summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/CMakeLists.txt11
-rw-r--r--src/application.cpp60
-rw-r--r--src/application.h4
-rw-r--r--src/bookmarks/bookmarkowner.cpp6
-rw-r--r--src/bookmarks/bookmarkprovider.cpp (renamed from src/bookmarks/bookmarksmanager.cpp)226
-rw-r--r--src/bookmarks/bookmarkprovider.h (renamed from src/bookmarks/bookmarksmanager.h)65
-rw-r--r--src/bookmarks/bookmarkscontextmenu.h6
-rw-r--r--src/bookmarks/bookmarkspanel.cpp2
-rw-r--r--src/bookmarks/bookmarkstoolbar.cpp2
-rw-r--r--src/bookmarks/bookmarkstoolbar.h7
-rw-r--r--src/bookmarks/bookmarkstreemodel.cpp25
-rw-r--r--src/data/CMakeLists.txt11
-rw-r--r--src/data/google.xml9
-rw-r--r--src/mainwindow.cpp6
-rw-r--r--src/mainwindow.h8
-rw-r--r--src/newtabpage.cpp4
-rw-r--r--src/rekonqui.rc1
-rw-r--r--src/search/opensearchengine.cpp274
-rw-r--r--src/search/opensearchengine.h110
-rw-r--r--src/search/opensearchmanager.cpp213
-rw-r--r--src/search/opensearchmanager.h108
-rw-r--r--src/search/opensearchreader.cpp174
-rw-r--r--src/search/opensearchreader.h55
-rw-r--r--src/search/opensearchwriter.cpp134
-rw-r--r--src/search/opensearchwriter.h56
-rw-r--r--src/search/searchengine.cpp (renamed from src/searchengine.cpp)0
-rw-r--r--src/search/searchengine.h (renamed from src/searchengine.h)0
-rw-r--r--src/settings/appearancewidget.cpp2
-rw-r--r--src/tabbar.cpp6
-rw-r--r--src/urlbar/bookmarkwidget.cpp2
-rw-r--r--src/urlbar/bookmarkwidget.h2
-rw-r--r--src/urlbar/completionwidget.cpp9
-rw-r--r--src/urlbar/listitem.cpp59
-rw-r--r--src/urlbar/listitem.h20
-rw-r--r--src/urlbar/urlbar.cpp25
-rw-r--r--src/urlbar/urlresolver.cpp301
-rw-r--r--src/urlbar/urlresolver.h31
-rw-r--r--src/webpage.cpp20
-rw-r--r--src/webtab.cpp8
-rw-r--r--src/webview.cpp16
-rw-r--r--src/zoombar.cpp3
41 files changed, 1704 insertions, 377 deletions
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index 151906b9..03c1e062 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -29,7 +29,6 @@ SET( rekonq_KDEINIT_SRCS
websnap.cpp
webview.cpp
webtab.cpp
- searchengine.cpp
#----------------------------------------
history/autosaver.cpp
history/historymanager.cpp
@@ -44,7 +43,7 @@ SET( rekonq_KDEINIT_SRCS
settings/webkitwidget.cpp
settings/networkwidget.cpp
#----------------------------------------
- bookmarks/bookmarksmanager.cpp
+ bookmarks/bookmarkprovider.cpp
bookmarks/bookmarkspanel.cpp
bookmarks/bookmarkstreemodel.cpp
bookmarks/bookmarksproxy.cpp
@@ -69,6 +68,12 @@ SET( rekonq_KDEINIT_SRCS
#----------------------------------------
analyzer/analyzerpanel.cpp
analyzer/networkanalyzer.cpp
+ #----------------------------------------
+ search/searchengine.cpp
+ search/opensearchwriter.cpp
+ search/opensearchreader.cpp
+ search/opensearchmanager.cpp
+ search/opensearchengine.cpp
)
@@ -94,6 +99,7 @@ INCLUDE_DIRECTORIES ( ${CMAKE_CURRENT_SOURCE_DIR}
${CMAKE_CURRENT_SOURCE_DIR}/rekonqpage
${CMAKE_CURRENT_SOURCE_DIR}/settings
${CMAKE_CURRENT_SOURCE_DIR}/analyzer
+ ${CMAKE_CURRENT_SOURCE_DIR}/search
${CMAKE_CURRENT_BINARY_DIR}
${KDE4_INCLUDES}
${QT4_INCLUDES}
@@ -113,6 +119,7 @@ KDE4_ADD_KDEINIT_EXECUTABLE( rekonq ${rekonq_KDEINIT_SRCS} main.cpp )
TARGET_LINK_LIBRARIES ( kdeinit_rekonq
${QT_LIBRARIES}
+ ${QT_QTSCRIPT_LIBRARY}
${QT_QTWEBKIT_LIBRARY}
${KDE4_KDEWEBKIT_LIBS}
${KDE4_KUTILS_LIBS}
diff --git a/src/application.cpp b/src/application.cpp
index 5cc3b460..db71c602 100644
--- a/src/application.cpp
+++ b/src/application.cpp
@@ -36,12 +36,13 @@
// Local Includes
#include "mainwindow.h"
#include "historymanager.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "mainview.h"
#include "webtab.h"
#include "urlbar.h"
#include "sessionmanager.h"
#include "adblockmanager.h"
+#include "opensearchmanager.h"
#include "webview.h"
#include "filterurljob.h"
#include "tabbar.h"
@@ -64,6 +65,7 @@ QWeakPointer<HistoryManager> Application::s_historyManager;
QWeakPointer<BookmarkProvider> Application::s_bookmarkProvider;
QWeakPointer<SessionManager> Application::s_sessionManager;
QWeakPointer<AdBlockManager> Application::s_adblockManager;
+QWeakPointer<OpenSearchManager> Application::s_opensearchManager;
Application::Application()
@@ -98,6 +100,9 @@ Application::~Application()
delete s_adblockManager.data();
s_adblockManager.clear();
+
+ delete s_opensearchManager.data();
+ s_opensearchManager.clear();
}
@@ -107,7 +112,7 @@ int Application::newInstance()
KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
// not that easy, indeed
- // We have to consider 3 variables here:
+ // We have to consider 3 variables here:
// 1) Is first load?
// 2) Are there arguments?
// 3) Is rekonq recovering from crash?
@@ -115,13 +120,13 @@ int Application::newInstance()
bool isFirstLoad = m_mainWindows.isEmpty();
bool areThereArguments = (args->count() > 0);
bool isRekonqCrashed = (ReKonfig::recoverOnCrash() == 1);
-
+
kDebug() << "is first load? " << isFirstLoad;
kDebug() << "are there arguments? " << areThereArguments;
kDebug() << "is rekonq crashed? " << isRekonqCrashed;
-
+
int exitValue = 1 * isFirstLoad + 2 * areThereArguments + 4 * isRekonqCrashed;
-
+
if(isRekonqCrashed)
{
if( isFirstLoad && sessionManager()->restoreSession() )
@@ -139,7 +144,7 @@ int Application::newInstance()
loadUrl( KUrl("about:blank"), Rekonq::NewFocusedTab);
}
}
-
+
if(areThereArguments)
{
KUrl::List urlList;
@@ -151,7 +156,7 @@ int Application::newInstance()
else
urlList += KUrl( args->arg(i) ); // "rekonq kde.org" || "rekonq kde:kdialog" case
}
-
+
if (isFirstLoad)
{
// No windows in the current desktop? No windows at all?
@@ -178,7 +183,7 @@ int Application::newInstance()
Q_FOREACH(const KUrl &u, urlList)
loadUrl(u, Rekonq::NewFocusedTab);
}
- }
+ }
}
else
{
@@ -218,16 +223,16 @@ int Application::newInstance()
break;
}
- }
+ }
}
-
-
+
+
if(isFirstLoad)
{
// give me some time to do the other things..
QTimer::singleShot(100, this, SLOT(postLaunch()));
}
-
+
return exitValue;
}
@@ -315,6 +320,17 @@ SessionManager *Application::sessionManager()
}
+OpenSearchManager *Application::opensearchManager()
+{
+ if (s_opensearchManager.isNull())
+ {
+ s_opensearchManager = new OpenSearchManager(instance());
+ s_opensearchManager.data()->setSearchProvider("google"); //TODO: use other suggestion engines
+ }
+ return s_opensearchManager.data();
+}
+
+
KIcon Application::icon(const KUrl &url)
{
// avoid infinite loop at startup
@@ -392,7 +408,7 @@ void Application::loadUrl(const KUrl& url, const Rekonq::OpenType& type)
Q_ASSERT( tabIndex != -1 );
UrlBar *barForTab = qobject_cast<UrlBar *>(w->mainView()->widgetBar()->widget(tabIndex));
barForTab->setQUrl(url);
-
+
WebView *view = tab->view();
if (view)
@@ -470,16 +486,16 @@ void Application::updateConfiguration()
{
MainView *mv = w.data()->mainView();
mv->updateTabBar();
-
+
if (b)
mv->tabBar()->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
else
mv->tabBar()->setSelectionBehaviorOnRemove(QTabBar::SelectRightTab);
}
- QWebSettings *defaultSettings = QWebSettings::globalSettings();
-
- // =========== Fonts ==============
+ QWebSettings *defaultSettings = QWebSettings::globalSettings();
+
+ // =========== Fonts ==============
defaultSettings->setFontFamily(QWebSettings::StandardFont, ReKonfig::standardFontFamily() );
defaultSettings->setFontFamily(QWebSettings::FixedFont, ReKonfig::fixedFontFamily() );
defaultSettings->setFontFamily(QWebSettings::SerifFont, ReKonfig::serifFontFamily() );
@@ -487,15 +503,15 @@ void Application::updateConfiguration()
defaultSettings->setFontFamily(QWebSettings::CursiveFont, ReKonfig::cursiveFontFamily());
defaultSettings->setFontFamily(QWebSettings::FantasyFont, ReKonfig::fantasyFontFamily());
- // compute font size
+ // compute font size
// (I have to admit I know nothing about these DPI questions..: copied from kwebkitpart, as someone suggested)
// font size in pixels = font size in inches × screen dpi
- int defaultFontSize = ReKonfig::defaultFontSize();
+ int defaultFontSize = ReKonfig::defaultFontSize();
int minimumFontSize = ReKonfig::minFontSize();
-
+
int logDpiY = mainWindow()->currentTab()->view()->logicalDpiY();
kDebug() << "Logical Dot per Inch Y: " << logDpiY;
-
+
float toPix = (logDpiY < 96.0)
? 96.0/72.0
: logDpiY/72.0 ;
@@ -503,7 +519,7 @@ void Application::updateConfiguration()
defaultSettings->setFontSize(QWebSettings::DefaultFontSize, qRound(defaultFontSize * toPix) );
defaultSettings->setFontSize(QWebSettings::MinimumFontSize, qRound(minimumFontSize * toPix) );
-
+
// ================ WebKit ============================
defaultSettings->setAttribute(QWebSettings::AutoLoadImages, ReKonfig::autoLoadImages());
defaultSettings->setAttribute(QWebSettings::DnsPrefetchEnabled, ReKonfig::dnsPrefetch());
diff --git a/src/application.h b/src/application.h
index 18c99afb..a08d883c 100644
--- a/src/application.h
+++ b/src/application.h
@@ -33,6 +33,8 @@
// Rekonq Includes
#include "rekonq_defines.h"
+#include "opensearchmanager.h"
+
// KDE Includes
#include <KUniqueApplication>
#include <KIcon>
@@ -111,6 +113,7 @@ public:
static BookmarkProvider *bookmarkProvider();
static SessionManager *sessionManager();
static AdBlockManager *adblockManager();
+ static OpenSearchManager *opensearchManager();
// DOWNLOADS MANAGEMENT METHODS
void addDownload(const QString &srcUrl, const QString &destUrl);
@@ -148,6 +151,7 @@ private:
static QWeakPointer<BookmarkProvider> s_bookmarkProvider;
static QWeakPointer<SessionManager> s_sessionManager;
static QWeakPointer<AdBlockManager> s_adblockManager;
+ static QWeakPointer<OpenSearchManager> s_opensearchManager;
MainWindowList m_mainWindows;
};
diff --git a/src/bookmarks/bookmarkowner.cpp b/src/bookmarks/bookmarkowner.cpp
index f47b978d..862a7de4 100644
--- a/src/bookmarks/bookmarkowner.cpp
+++ b/src/bookmarks/bookmarkowner.cpp
@@ -32,13 +32,15 @@
// Local Includes
#include "application.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "mainwindow.h"
#include "webtab.h"
#include "mainview.h"
// KDE Includes
+#include <KAction>
#include <KBookmarkDialog>
+#include <KLocalizedString>
#include <KMessageBox>
// Qt Includes
@@ -163,7 +165,7 @@ void BookmarkOwner::openBookmarkFolder(const KBookmark &bookmark)
return;
}
- foreach (KUrl url, urlList)
+ Q_FOREACH(const KUrl &url, urlList)
{
emit openUrl(url, Rekonq::NewFocusedTab);
}
diff --git a/src/bookmarks/bookmarksmanager.cpp b/src/bookmarks/bookmarkprovider.cpp
index dc545698..41704f58 100644
--- a/src/bookmarks/bookmarksmanager.cpp
+++ b/src/bookmarks/bookmarkprovider.cpp
@@ -28,17 +28,17 @@
// Self Includes
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
// Local Includes
#include "application.h"
-#include "mainwindow.h"
#include "bookmarkspanel.h"
#include "bookmarkscontextmenu.h"
#include "bookmarkstoolbar.h"
#include "bookmarkowner.h"
// KDE Includes
+#include <KActionCollection>
#include <KStandardDirs>
// Qt Includes
@@ -50,35 +50,27 @@ BookmarkProvider::BookmarkProvider(QObject *parent)
, m_manager(0)
, m_owner(0)
, m_actionCollection(new KActionCollection(this))
- , _bookmarkActionMenu(0)
{
kDebug() << "Loading Bookmarks Manager...";
- KUrl bookfile = KUrl("~/.kde/share/apps/konqueror/bookmarks.xml"); // share konqueror bookmarks
+ QString bookmarkFile = KStandardDirs::locate("data", "konqueror/bookmarks.xml"); // share konqueror's bookmarks
- if (!QFile::exists(bookfile.path()))
+ if (!QFile::exists(bookmarkFile))
{
- bookfile = KUrl("~/.kde4/share/apps/konqueror/bookmarks.xml");
- if (!QFile::exists(bookfile.path()))
- {
- QString bookmarksDefaultPath = KStandardDirs::locate("appdata" , "defaultbookmarks.xbel");
- QFile bkms(bookmarksDefaultPath);
- QString bookmarksPath = KStandardDirs::locateLocal("appdata", "bookmarks.xml", true);
- bookmarksPath.replace("rekonq", "konqueror");
- bkms.copy(bookmarksPath);
-
- bookfile = KUrl(bookmarksPath);
- }
+ bookmarkFile = KStandardDirs::locateLocal("appdata", "bookmarks.xml", true);
+ QFile bkms( KStandardDirs::locate("appdata" , "defaultbookmarks.xbel") );
+ bkms.copy(bookmarkFile);
}
- m_manager = KBookmarkManager::managerForFile(bookfile.path(), "rekonq");
+ m_manager = KBookmarkManager::managerForFile(bookmarkFile, "rekonq");
connect(m_manager, SIGNAL(changed(const QString &, const QString &)),
this, SLOT(slotBookmarksChanged(const QString &, const QString &)));
// setup menu
m_owner = new BookmarkOwner(m_manager, this);
- connect(m_owner, SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType &)), this, SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType &)));
+ connect(m_owner, SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType&)),
+ this, SIGNAL(openUrl(const KUrl&, const Rekonq::OpenType&)));
KAction *a = KStandardAction::addBookmark(this, SLOT(slotAddBookmark()), this);
m_actionCollection->addAction(QL1S("rekonq_add_bookmark"), a);
@@ -89,12 +81,26 @@ BookmarkProvider::BookmarkProvider(QObject *parent)
BookmarkProvider::~BookmarkProvider()
{
- delete m_actionCollection;
- delete m_owner;
delete m_manager;
}
+KActionMenu* BookmarkProvider::bookmarkActionMenu(QWidget *parent)
+{
+ kDebug() << "new Bookmarks menu...";
+
+ KMenu *menu = new KMenu(parent);
+ KActionMenu *bookmarkActionMenu = new KActionMenu(menu);
+ bookmarkActionMenu->setMenu(menu);
+ bookmarkActionMenu->setText(i18n("&Bookmarks"));
+ new BookmarkMenu(m_manager, m_owner, menu, m_actionCollection);
+
+ kDebug() << "new Bookmarks menu... DONE";
+
+ return bookmarkActionMenu;
+}
+
+
void BookmarkProvider::registerBookmarkBar(BookmarkToolBar *toolbar)
{
if (m_bookmarkToolBars.contains(toolbar))
@@ -104,40 +110,76 @@ void BookmarkProvider::registerBookmarkBar(BookmarkToolBar *toolbar)
m_bookmarkToolBars.append(toolbar);
toolbar->toolBar()->setContextMenuPolicy(Qt::CustomContextMenu);
- connect(toolbar->toolBar(), SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(contextMenu(const QPoint &)));
+ connect(toolbar->toolBar(), SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(contextMenu(const QPoint&)));
kDebug() << "new bookmark bar... DONE!";
}
-void BookmarkProvider::removeToolBar(BookmarkToolBar *toolbar)
+void BookmarkProvider::removeBookmarkBar(BookmarkToolBar *toolbar)
{
m_bookmarkToolBars.removeOne(toolbar);
}
-void BookmarkProvider::slotBookmarksChanged(const QString &group, const QString &caller)
+void BookmarkProvider::registerBookmarkPanel(BookmarksPanel *panel)
{
- Q_UNUSED(group)
- Q_UNUSED(caller)
-
- foreach(BookmarkToolBar *bookmarkToolBar, m_bookmarkToolBars)
+ if (panel && !m_bookmarkPanels.contains(panel))
{
- if (bookmarkToolBar)
- {
- bookmarkToolBar->toolBar()->clear();
- fillBookmarkBar(bookmarkToolBar);
- }
+ m_bookmarkPanels.append(panel);
+ connect(panel, SIGNAL(expansionChanged()), this, SLOT(slotPanelChanged()));
}
}
-QAction *BookmarkProvider::actionByName(const QString &name)
+void BookmarkProvider::removeBookmarkPanel(BookmarksPanel *panel)
+{
+ if (!panel)
+ return;
+
+ m_bookmarkPanels.removeOne(panel);
+ panel->disconnect(this);
+
+ if (m_bookmarkPanels.isEmpty())
+ Application::bookmarkProvider()->bookmarkManager()->emitChanged();
+}
+
+
+QAction* BookmarkProvider::actionByName(const QString &name)
{
QAction *action = m_actionCollection->action(name);
if (action)
return action;
- return new QAction(this); // return empty object instead of NULL pointer
+ return new QAction(this);
+}
+
+
+KBookmarkGroup BookmarkProvider::rootGroup()
+{
+ return m_manager->root();
+}
+
+
+QList<KBookmark> BookmarkProvider::find(const QString &text)
+{
+ QList<KBookmark> list;
+
+ KBookmarkGroup root = Application::bookmarkProvider()->rootGroup();
+ if (!root.isNull())
+ for (KBookmark bookmark = root.first(); !bookmark.isNull(); bookmark = root.next(bookmark))
+ find(&list, bookmark, text);
+
+ return list;
+}
+
+
+KBookmark BookmarkProvider::bookmarkForUrl(const KUrl &url)
+{
+ KBookmarkGroup root = rootGroup();
+ if (root.isNull())
+ return KBookmark();
+
+ return bookmarkForUrl(root, url);
}
@@ -150,7 +192,7 @@ void BookmarkProvider::contextMenu(const QPoint &point)
if (!bookmarkToolBar)
return;
- KBookmarkActionInterface* action = dynamic_cast<KBookmarkActionInterface *>(bookmarkToolBar->actionAt(point));
+ KBookmarkActionInterface *action = dynamic_cast<KBookmarkActionInterface*>(bookmarkToolBar->actionAt(point));
if (!action)
return;
@@ -159,18 +201,16 @@ void BookmarkProvider::contextMenu(const QPoint &point)
}
-KActionMenu* BookmarkProvider::bookmarkActionMenu(QWidget *parent)
+void BookmarkProvider::slotBookmarksChanged(const QString& /*groupAddress*/, const QString& /*caller*/)
{
- kDebug() << "new Bookmarks Menu...";
-
- KMenu *menu = new KMenu(parent);
- _bookmarkActionMenu = new KActionMenu(parent);
- _bookmarkActionMenu->setMenu(menu);
- _bookmarkActionMenu->setText(i18n("&Bookmarks"));
- new BookmarkMenu(m_manager, m_owner, menu, m_actionCollection);
-
- kDebug() << "new Bookmarks Menu...DONE";
- return _bookmarkActionMenu;
+ foreach(BookmarkToolBar *bookmarkToolBar, m_bookmarkToolBars)
+ {
+ if (bookmarkToolBar)
+ {
+ bookmarkToolBar->toolBar()->clear();
+ fillBookmarkBar(bookmarkToolBar);
+ }
+ }
}
@@ -187,19 +227,19 @@ void BookmarkProvider::fillBookmarkBar(BookmarkToolBar *toolBar)
KBookmarkActionMenu *menuAction = new KBookmarkActionMenu(bookmark.toGroup(), this);
menuAction->setDelayed(false);
new BookmarkMenu(bookmarkManager(), bookmarkOwner(), menuAction->menu(), bookmark.address());
+
connect(menuAction->menu(), SIGNAL(aboutToShow()), toolBar, SLOT(menuDisplayed()));
connect(menuAction->menu(), SIGNAL(aboutToHide()), toolBar, SLOT(menuHidden()));
+
toolBar->toolBar()->addAction(menuAction);
}
-
else if (bookmark.isSeparator())
{
toolBar->toolBar()->addSeparator();
}
-
else
{
- KBookmarkAction* action = new KBookmarkAction(bookmark, m_owner, this);
+ KBookmarkAction *action = new KBookmarkAction(bookmark, m_owner, this);
action->setIconText(action->iconText().replace('&', "&&"));
connect(action, SIGNAL(hovered()), toolBar, SLOT(actionHovered()));
toolBar->toolBar()->addAction(action);
@@ -209,82 +249,13 @@ void BookmarkProvider::fillBookmarkBar(BookmarkToolBar *toolBar)
}
-KBookmarkGroup BookmarkProvider::rootGroup()
-{
- return m_manager->root();
-}
-
-
-QList<KBookmark> BookmarkProvider::find(QString text)
-{
- QList<KBookmark> list;
- KBookmarkGroup bookGroup = Application::bookmarkProvider()->rootGroup();
- if (bookGroup.isNull())
- {
- return list;
- }
-
- KBookmark bookmark = bookGroup.first();
- while (!bookmark.isNull())
- {
- list = find(list, bookmark, text);
- bookmark = bookGroup.next(bookmark);
- }
-
- return list;
-}
-
-
-QList<KBookmark> BookmarkProvider::find(QList<KBookmark> list, const KBookmark &bookmark, QString text)
-{
- if (bookmark.isGroup())
- {
- KBookmarkGroup group = bookmark.toGroup();
- KBookmark bm = group.first();
- while (!bm.isNull())
- {
- list = find(list, bm, text); // it is .bookfolder
- bm = group.next(bm);
- }
- }
- else if (bookmark.url().url().contains(text) || bookmark.fullText().contains(text))
- {
- list << bookmark;
- }
-
- return list;
-}
-
-
void BookmarkProvider::slotAddBookmark()
{
- KBookmarkGroup parentBookmark = rootGroup();
- parentBookmark.addBookmark(bookmarkOwner()->currentTitle(), bookmarkOwner()->currentUrl());
+ rootGroup().addBookmark(bookmarkOwner()->currentTitle(), bookmarkOwner()->currentUrl());
bookmarkManager()->emitChanged();
}
-void BookmarkProvider::registerBookmarkPanel(BookmarksPanel *panel)
-{
- if (panel && !m_bookmarkPanels.contains(panel))
- {
- m_bookmarkPanels.append(panel);
- connect(panel, SIGNAL(expansionChanged()), this, SLOT(slotPanelChanged()));
- }
-}
-
-
-void BookmarkProvider::removeBookmarkPanel(BookmarksPanel *panel)
-{
- m_bookmarkPanels.removeOne(panel);
-
- if (m_bookmarkPanels.isEmpty())
- {
- Application::bookmarkProvider()->bookmarkManager()->emitChanged();
- }
-}
-
-
void BookmarkProvider::slotPanelChanged()
{
foreach (BookmarksPanel *panel, m_bookmarkPanels)
@@ -295,17 +266,18 @@ void BookmarkProvider::slotPanelChanged()
}
-KBookmark BookmarkProvider::bookmarkForUrl(const KUrl &url)
+void BookmarkProvider::find(QList<KBookmark> *list, const KBookmark &bookmark, const QString &text)
{
- KBookmark found;
-
- KBookmarkGroup root = rootGroup();
- if (root.isNull())
+ if (bookmark.isGroup())
{
- return found;
+ KBookmarkGroup group = bookmark.toGroup();
+ for (KBookmark bm = group.first(); !bm.isNull(); bm = group.next(bm))
+ find(list, bm, text);
+ }
+ else if (bookmark.url().url().contains(text) || bookmark.fullText().contains(text))
+ {
+ *list << bookmark;
}
-
- return bookmarkForUrl(root, url);
}
diff --git a/src/bookmarks/bookmarkscontextmenu.h b/src/bookmarks/bookmarkscontextmenu.h
index 424f8da4..a6691fdd 100644
--- a/src/bookmarks/bookmarkscontextmenu.h
+++ b/src/bookmarks/bookmarkscontextmenu.h
@@ -24,8 +24,8 @@
* ============================================================ */
-#ifndef BOOKMARKCONTEXTMENU_H
-#define BOOKMARKCONTEXTMENU_H
+#ifndef BOOKMARKS_CONTEXT_MENU_H
+#define BOOKMARKS_CONTEXT_MENU_H
// KDE Includes
#include <KBookmarkMenu>
@@ -50,4 +50,4 @@ private:
BookmarkOwner *bmOwner;
};
-#endif // BOOKMARKCONTEXTMENU_H
+#endif // BOOKMARKS_CONTEXT_MENU_H
diff --git a/src/bookmarks/bookmarkspanel.cpp b/src/bookmarks/bookmarkspanel.cpp
index 1b561515..08f99155 100644
--- a/src/bookmarks/bookmarkspanel.cpp
+++ b/src/bookmarks/bookmarkspanel.cpp
@@ -30,7 +30,7 @@
// Local Includes
#include "application.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "bookmarkstreemodel.h"
#include "bookmarksproxy.h"
#include "bookmarkscontextmenu.h"
diff --git a/src/bookmarks/bookmarkstoolbar.cpp b/src/bookmarks/bookmarkstoolbar.cpp
index bce2bd1e..64e9c3b9 100644
--- a/src/bookmarks/bookmarkstoolbar.cpp
+++ b/src/bookmarks/bookmarkstoolbar.cpp
@@ -33,7 +33,7 @@
#include "bookmarkscontextmenu.h"
#include "mainwindow.h"
#include "application.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "bookmarkowner.h"
// Qt Includes
diff --git a/src/bookmarks/bookmarkstoolbar.h b/src/bookmarks/bookmarkstoolbar.h
index 5991a032..54a430e3 100644
--- a/src/bookmarks/bookmarkstoolbar.h
+++ b/src/bookmarks/bookmarkstoolbar.h
@@ -30,8 +30,6 @@
// KDE Includes
#include <KBookmarkMenu>
-#include <KToolBar>
-
/**
* This class represent the rekonq bookmarks menu.
@@ -69,6 +67,11 @@ private:
// ------------------------------------------------------------------------------
+
+// KDE Includes
+#include <KToolBar>
+
+
/**
* This class manage the bookmark toolbar.
* Some events from the toolbar are handled to allow the drag and drop
diff --git a/src/bookmarks/bookmarkstreemodel.cpp b/src/bookmarks/bookmarkstreemodel.cpp
index 7f0bf66f..ee19daf1 100644
--- a/src/bookmarks/bookmarkstreemodel.cpp
+++ b/src/bookmarks/bookmarkstreemodel.cpp
@@ -30,7 +30,11 @@
// Local Includes
#include "application.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
+
+// KDE Includes
+#include <KBookmarkManager>
+#include <KLocalizedString>
// Qt Includes
#include <QtCore/QMimeData>
@@ -56,28 +60,27 @@ QVariant BtmItem::data(int role) const
if (role == Qt::DisplayRole)
return m_kbm.text();
+
if (role == Qt::DecorationRole)
return KIcon(m_kbm.icon());
+
if (role == Qt::UserRole)
return m_kbm.url();
+
if (role == Qt::ToolTipRole)
{
- QString tooltip = "";
-
- if (!m_kbm.fullText().isEmpty())
- {
- tooltip += m_kbm.fullText();
- }
+ QString tooltip = m_kbm.fullText();
if (m_kbm.isGroup())
- {
tooltip += i18ncp("%1=Number of items in bookmark folder", " (1 item)", " (%1 items)", childCount());
- }
- if (!m_kbm.url().url().isEmpty())
+
+ QString url = m_kbm.url().url();
+ if (!url.isEmpty())
{
if (!tooltip.isEmpty())
tooltip += '\n';
- tooltip += m_kbm.url().url();
+ tooltip += url;
}
+
return tooltip;
}
diff --git a/src/data/CMakeLists.txt b/src/data/CMakeLists.txt
index 5f0ac164..ed1ada34 100644
--- a/src/data/CMakeLists.txt
+++ b/src/data/CMakeLists.txt
@@ -1,3 +1,4 @@
+# image files
INSTALL(
FILES
bg2.png bg.png tile.gif category.png button.png
@@ -6,20 +7,30 @@ INSTALL(
DESTINATION ${DATA_INSTALL_DIR}/rekonq/pics
)
+# default bookmarks
INSTALL(
FILES
defaultbookmarks.xbel
DESTINATION ${DATA_INSTALL_DIR}/rekonq
)
+# .desktop file
INSTALL(
FILES rekonq.desktop
DESTINATION ${XDG_APPS_INSTALL_DIR}
)
+# htmls
INSTALL(
FILES
rekonqinfo.html
home.html
DESTINATION ${DATA_INSTALL_DIR}/rekonq/htmls
)
+
+# opensearch engines
+INSTALL(
+ FILES
+ google.xml
+ DESTINATION ${DATA_INSTALL_DIR}/rekonq/opensearch
+)
diff --git a/src/data/google.xml b/src/data/google.xml
new file mode 100644
index 00000000..622a0737
--- /dev/null
+++ b/src/data/google.xml
@@ -0,0 +1,9 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<OpenSearchDescription xmlns="http://a9.com/-/spec/opensearch/1.1/">
+ <ShortName>Google</ShortName>
+ <Description>Google Web Search</Description>
+ <Url method="get" type="text/html" template="http://www.google.com/search?hl={language}&amp;lr=lang_{language}&amp;q={searchTerms}"/>
+ <Url method="get" type="application/x-suggestions+json" template="http://suggestqueries.google.com/complete/search?json=t&amp;hl={language}&amp;q={searchTerms}&amp;nolabels=t"/>
+ <Image width="16" height="16">http://www.google.com/favicon.ico</Image>
+</OpenSearchDescription>
+
diff --git a/src/mainwindow.cpp b/src/mainwindow.cpp
index 1017582e..4f9d6dab 100644
--- a/src/mainwindow.cpp
+++ b/src/mainwindow.cpp
@@ -37,7 +37,7 @@
// Local Includes
#include "settingsdialog.h"
#include "historymanager.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "bookmarkstoolbar.h"
#include "webtab.h"
#include "mainview.h"
@@ -164,7 +164,7 @@ MainWindow::MainWindow()
MainWindow::~MainWindow()
{
- Application::bookmarkProvider()->removeToolBar(m_bookmarksBar);
+ Application::bookmarkProvider()->removeBookmarkBar(m_bookmarksBar);
Application::bookmarkProvider()->removeBookmarkPanel(m_bookmarksPanel);
Application::instance()->removeMainWindow(this);
@@ -212,7 +212,7 @@ void MainWindow::initBookmarkBar()
if (m_bookmarksBar)
{
- Application::bookmarkProvider()->removeToolBar(m_bookmarksBar);
+ Application::bookmarkProvider()->removeBookmarkBar(m_bookmarksBar);
delete m_bookmarksBar;
}
m_bookmarksBar = new BookmarkToolBar(XMLGUIBkBar, this);
diff --git a/src/mainwindow.h b/src/mainwindow.h
index e135adca..3aa57f5c 100644
--- a/src/mainwindow.h
+++ b/src/mainwindow.h
@@ -35,8 +35,8 @@
#include "rekonq_defines.h"
// Local Includes
-#include "bookmarksmanager.h"
-
+#include "bookmarkprovider.h"
+
// KDE Includes
#include <KXmlGuiWindow>
#include <KActionCollection>
@@ -75,7 +75,7 @@ public:
inline MainView *mainView() const { return m_view; }
inline QAction *actionByName(const QString &name) { return actionCollection()->action(name); }
-
+
WebTab *currentTab() const;
virtual QSize sizeHint() const;
void setWidgetsVisible(bool makeFullScreen);
@@ -123,7 +123,7 @@ protected:
void keyPressEvent(QKeyEvent *event);
bool queryClose();
-
+
private slots:
void postLaunch();
void browserLoading(bool);
diff --git a/src/newtabpage.cpp b/src/newtabpage.cpp
index 78496bc2..44b76e11 100644
--- a/src/newtabpage.cpp
+++ b/src/newtabpage.cpp
@@ -34,7 +34,7 @@
// Local Includes
#include "historymodels.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "application.h"
#include "mainwindow.h"
#include "mainview.h"
@@ -47,9 +47,11 @@
#include <KConfig>
#include <KDialog>
#include <KCalendarSystem>
+#include <KBookmarkManager>
// Qt Includes
#include <QtCore/QFile>
+#include <QtGui/QAction>
NewTabPage::NewTabPage(QWebFrame *frame)
diff --git a/src/rekonqui.rc b/src/rekonqui.rc
index 8b9a51cb..cc2103b4 100644
--- a/src/rekonqui.rc
+++ b/src/rekonqui.rc
@@ -88,7 +88,6 @@
<Separator />
<Action name="stop_reload" />
<Action name="url_bar" />
- <Action name="bookmarksActionMenu" />
<Action name="rekonq_tools" />
</ToolBar>
diff --git a/src/search/opensearchengine.cpp b/src/search/opensearchengine.cpp
new file mode 100644
index 00000000..78e50980
--- /dev/null
+++ b/src/search/opensearchengine.cpp
@@ -0,0 +1,274 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2009 by Christian Franke <cfchris6@ts2server.com>
+* Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+// Self Includes
+#include "opensearchengine.h"
+
+// Qt Includes
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
+#include <QtScript/QScriptEngine>
+#include <QtScript/QScriptValue>
+
+
+OpenSearchEngine::OpenSearchEngine(QObject *)
+ : m_scriptEngine(0)
+{
+}
+
+
+OpenSearchEngine::~OpenSearchEngine()
+{
+ if (m_scriptEngine)
+ {
+ delete m_scriptEngine;
+ }
+}
+
+
+QString OpenSearchEngine::parseTemplate(const QString &searchTerm, const QString &searchTemplate)
+{
+ QString result = searchTemplate;
+ result.replace(QL1S("{count}"), QL1S("20"));
+ result.replace(QL1S("{startIndex}"), QL1S("0"));
+ result.replace(QL1S("{startPage}"), QL1S("0"));
+ // TODO - get setting from KDE
+ result.replace(QL1S("{language}"), QL1S("en-US"));
+ result.replace(QL1S("{inputEncoding}"), QL1S("UTF-8"));
+ result.replace(QL1S("{outputEncoding}"), QL1S("UTF-8"));
+ result.replace(QL1S("{searchTerms}"), searchTerm);
+
+ return result;
+}
+
+
+QString OpenSearchEngine::name() const
+{
+ return m_name;
+}
+
+
+void OpenSearchEngine::setName(const QString &name)
+{
+ m_name = name;
+}
+
+
+QString OpenSearchEngine::description() const
+{
+ return m_description;
+}
+
+
+void OpenSearchEngine::setDescription(const QString &description)
+{
+ m_description = description;
+}
+
+
+QString OpenSearchEngine::searchUrlTemplate() const
+{
+ return m_searchUrlTemplate;
+}
+
+
+void OpenSearchEngine::setSearchUrlTemplate(const QString &searchUrlTemplate)
+{
+ m_searchUrlTemplate = searchUrlTemplate;
+}
+
+
+KUrl OpenSearchEngine::searchUrl(const QString &searchTerm) const
+{
+ if (m_searchUrlTemplate.isEmpty())
+ {
+ return KUrl();
+ }
+
+ KUrl retVal = KUrl::fromEncoded(parseTemplate(searchTerm, m_searchUrlTemplate).toUtf8());
+
+ QList<Parameter>::const_iterator i;
+ for ( i = m_searchParameters.constBegin(); i != m_searchParameters.constEnd(); ++i)
+ {
+ retVal.addQueryItem(i->first, parseTemplate(searchTerm, i->second));
+ }
+
+ return retVal;
+}
+
+
+bool OpenSearchEngine::providesSuggestions() const
+{
+ return !m_suggestionsUrlTemplate.isEmpty();
+}
+
+
+QString OpenSearchEngine::suggestionsUrlTemplate() const
+{
+ return m_suggestionsUrlTemplate;
+}
+
+
+void OpenSearchEngine::setSuggestionsUrlTemplate(const QString &suggestionsUrlTemplate)
+{
+ m_suggestionsUrlTemplate = suggestionsUrlTemplate;
+}
+
+
+KUrl OpenSearchEngine::suggestionsUrl(const QString &searchTerm) const
+{
+ if (m_suggestionsUrlTemplate.isEmpty())
+ {
+ return KUrl();
+ }
+
+ KUrl retVal = KUrl::fromEncoded(parseTemplate(searchTerm, m_suggestionsUrlTemplate).toUtf8());
+
+ QList<Parameter>::const_iterator i;
+ for( i = m_suggestionsParameters.constBegin(); i != m_suggestionsParameters.constEnd(); ++i)
+ {
+ retVal.addQueryItem(i->first, parseTemplate(searchTerm, i->second));
+ }
+ return retVal;
+}
+
+
+QList<OpenSearchEngine::Parameter> OpenSearchEngine::searchParameters() const
+{
+ return m_searchParameters;
+}
+
+
+void OpenSearchEngine::setSearchParameters(const QList<Parameter> &searchParameters)
+{
+ m_searchParameters = searchParameters;
+}
+
+
+QList<OpenSearchEngine::Parameter> OpenSearchEngine::suggestionsParameters() const
+{
+ return m_suggestionsParameters;
+}
+
+
+void OpenSearchEngine::setSuggestionsParameters(const QList<Parameter> &suggestionsParameters)
+{
+ m_suggestionsParameters = suggestionsParameters;
+}
+
+
+QString OpenSearchEngine::imageUrl() const
+{
+ return m_imageUrl;
+}
+
+
+void OpenSearchEngine::setImageUrl(const QString &imageUrl)
+{
+ m_imageUrl = imageUrl;
+}
+
+
+QImage OpenSearchEngine::image() const
+{
+ return m_image;
+}
+
+
+void OpenSearchEngine::setImage(const QImage &image)
+{
+ m_image = image;
+}
+
+
+bool OpenSearchEngine::isValid() const
+{
+ return (!m_name.isEmpty() && !m_searchUrlTemplate.isEmpty());
+}
+
+
+bool OpenSearchEngine::operator==(const OpenSearchEngine &other) const
+{
+ return (m_name == other.m_name
+ && m_description == other.m_description
+ && m_imageUrl == other.m_imageUrl
+ && m_searchUrlTemplate == other.m_searchUrlTemplate
+ && m_suggestionsUrlTemplate == other.m_suggestionsUrlTemplate
+ && m_searchParameters == other.m_searchParameters
+ && m_suggestionsParameters == other.m_suggestionsParameters);
+}
+
+
+bool OpenSearchEngine::operator<(const OpenSearchEngine &other) const
+{
+ return (m_name < other.m_name);
+}
+
+
+QStringList OpenSearchEngine::parseSuggestion(const QByteArray &resp)
+{
+ QString response = QString::fromLocal8Bit(resp);
+ response = response.trimmed();
+
+ if (response.isEmpty())
+ {
+ return QStringList();
+ }
+
+ if ( !response.startsWith(QL1C('['))
+ || !response.endsWith(QL1C(']'))
+ )
+ {
+ return QStringList();
+ }
+
+ if (!m_scriptEngine)
+ {
+ m_scriptEngine = new QScriptEngine();
+ }
+
+ // Evaluate the JSON response using QtScript.
+ if (!m_scriptEngine->canEvaluate(response))
+ {
+ return QStringList();
+ }
+
+ QScriptValue responseParts = m_scriptEngine->evaluate(response);
+
+ if (!responseParts.property(1).isArray())
+ {
+ return QStringList();
+ }
+
+ QStringList suggestionsList;
+ qScriptValueToSequence(responseParts.property(1), suggestionsList);
+
+ return suggestionsList;
+}
diff --git a/src/search/opensearchengine.h b/src/search/opensearchengine.h
new file mode 100644
index 00000000..f2329624
--- /dev/null
+++ b/src/search/opensearchengine.h
@@ -0,0 +1,110 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2009 by Christian Franke <cfchris6@ts2server.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+#ifndef OPENSEARCHENGINE_H
+#define OPENSEARCHENGINE_H
+
+
+// Rekonq Includes
+#include "rekonq_defines.h"
+
+// KDE Includes
+#include <KUrl>
+
+// Qt Includes
+#include <QtCore/QPair>
+#include <QtGui/QImage>
+
+// Forward Declarations
+class QNetworkAccessManager;
+class QNetworkReply;
+class QScriptEngine;
+
+
+class OpenSearchEngine
+{
+public:
+ typedef QPair<QString, QString> Parameter;
+
+ OpenSearchEngine(QObject *parent = 0);
+ ~OpenSearchEngine();
+
+ QString name() const;
+ void setName(const QString &name);
+
+ QString description() const;
+ void setDescription(const QString &description);
+
+ QString searchUrlTemplate() const;
+ void setSearchUrlTemplate(const QString &searchUrl);
+ KUrl searchUrl(const QString &searchTerm) const;
+
+ bool providesSuggestions() const;
+
+ QString suggestionsUrlTemplate() const;
+ void setSuggestionsUrlTemplate(const QString &suggestionsUrl);
+ KUrl suggestionsUrl(const QString &searchTerm) const;
+
+ QList<Parameter> searchParameters() const;
+ void setSearchParameters(const QList<Parameter> &searchParameters);
+
+ QList<Parameter> suggestionsParameters() const;
+ void setSuggestionsParameters(const QList<Parameter> &suggestionsParameters);
+
+ QString imageUrl() const;
+ void setImageUrl(const QString &url);
+
+ QImage image() const;
+ void setImage(const QImage &image);
+
+ bool isValid() const;
+
+ bool operator==(const OpenSearchEngine &other) const;
+ bool operator<(const OpenSearchEngine &other) const;
+
+ QStringList parseSuggestion(const QByteArray &response);
+
+ static QString parseTemplate(const QString &searchTerm, const QString &searchTemplate);
+
+private:
+ QString m_name;
+ QString m_description;
+
+ QString m_imageUrl;
+ QImage m_image;
+
+ QString m_searchUrlTemplate;
+ QString m_suggestionsUrlTemplate;
+ QList<Parameter> m_searchParameters;
+ QList<Parameter> m_suggestionsParameters;
+
+ QScriptEngine *m_scriptEngine;
+};
+
+#endif // OPENSEARCHENGINE_H
diff --git a/src/search/opensearchmanager.cpp b/src/search/opensearchmanager.cpp
new file mode 100644
index 00000000..463c0a11
--- /dev/null
+++ b/src/search/opensearchmanager.cpp
@@ -0,0 +1,213 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+// Self Includes
+#include "opensearchmanager.h"
+#include "opensearchmanager.moc"
+
+// Local Includes
+#include "opensearchengine.h"
+#include "opensearchreader.h"
+#include "opensearchwriter.h"
+
+// KDE Includes
+#include <KDebug>
+#include <KGlobal>
+#include <KStandardDirs>
+#include <KUrl>
+#include <kio/scheduler.h>
+
+// Qt Includes
+#include <QtCore/QFile>
+
+
+OpenSearchManager::OpenSearchManager(QObject *parent)
+ : QObject(parent)
+ , m_activeEngine(0)
+{
+ m_state = IDLE;
+}
+
+
+OpenSearchManager::~OpenSearchManager()
+{
+ qDeleteAll(m_enginesMap.values());
+ m_enginesMap.clear();
+}
+
+
+void OpenSearchManager::setSearchProvider(const QString &searchProvider)
+{
+ m_activeEngine = 0;
+
+ if (!m_enginesMap.contains(searchProvider))
+ {
+ const QString fileName = KGlobal::dirs()->findResource("data", "rekonq/opensearch/" + searchProvider + ".xml");
+ kDebug() << searchProvider << " file name path: " << fileName;
+ if (fileName.isEmpty())
+ {
+ kDebug() << "OpenSearch file name empty";
+ return;
+ }
+ QFile file(fileName);
+
+ if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+ {
+ kDebug() << "Cannot open opensearch description file: " + fileName;
+ return;
+ }
+
+ OpenSearchReader reader;
+ OpenSearchEngine *engine = reader.read(&file);
+
+ if (engine)
+ {
+ m_enginesMap.insert(searchProvider, engine);
+ }
+ else
+ {
+ return;
+ }
+ }
+
+ m_activeEngine = m_enginesMap.value(searchProvider);
+}
+
+
+bool OpenSearchManager::isSuggestionAvailable()
+{
+ return m_activeEngine != 0;
+}
+
+
+void OpenSearchManager::addOpenSearchEngine(const KUrl &url, const QString &title)
+{
+ Q_UNUSED(title);
+
+ m_jobData.clear();
+
+ if (m_state != IDLE)
+ {
+ // TODO: cancel job
+ }
+
+ m_state = REQ_DESCRIPTION;
+ KIO::TransferJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+ connect(job, SIGNAL(data(KIO::Job *, const QByteArray &)), this, SLOT(dataReceived(KIO::Job *, const QByteArray &)));
+ connect(job, SIGNAL(result(KJob *)), this, SLOT(jobFinished(KJob *)));
+}
+
+
+void OpenSearchManager::requestSuggestion(const QString &searchText)
+{
+ if (!m_activeEngine)
+ return;
+
+ if (m_state != IDLE)
+ {
+ // TODO: cancel job
+ }
+ m_state = REQ_SUGGESTION;
+
+ KUrl url = m_activeEngine->suggestionsUrl(searchText);
+ kDebug() << "Requesting for suggestions: " << url.url();
+ m_jobData.clear();
+
+ KIO::TransferJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
+ connect(job, SIGNAL(data(KIO::Job *, const QByteArray &)), this, SLOT(dataReceived(KIO::Job *, const QByteArray &)));
+ connect(job, SIGNAL(result(KJob *)), this, SLOT(jobFinished(KJob *)));
+}
+
+
+void OpenSearchManager::dataReceived(KIO::Job *job, const QByteArray &data)
+{
+ Q_UNUSED(job);
+ m_jobData.append(data);
+}
+
+
+void OpenSearchManager::jobFinished(KJob *job)
+{
+ if (job->error())
+ return; // just silently return
+
+ if (m_state == REQ_SUGGESTION)
+ {
+ const QStringList suggestionsList = m_activeEngine->parseSuggestion(m_jobData);
+ kDebug() << "Received suggestion from " << m_activeEngine->name() << ": " << suggestionsList;
+
+ emit suggestionReceived(suggestionsList);
+ return;
+ }
+
+ if (m_state == REQ_DESCRIPTION)
+ {
+ OpenSearchReader reader;
+ OpenSearchEngine *engine = reader.read(m_jobData);
+ if (engine)
+ {
+ m_enginesMap.insert(engine->name(), engine);
+ QString path = KGlobal::dirs()->findResource("data", "rekonq/opensearch/");
+ QString fileName = trimmedEngineName(engine->name());
+ QFile file(path + fileName + ".xml");
+ OpenSearchWriter writer;
+ writer.write(&file, engine);
+
+ QString searchUrl = OpenSearchEngine::parseTemplate("\\{@}", engine->searchUrlTemplate());
+ emit openSearchEngineAdded(engine->name(), searchUrl, fileName);
+ }
+ else
+ {
+ kFatal() << "Error while adding new open search engine";
+ }
+ }
+}
+
+
+QString OpenSearchManager::trimmedEngineName(const QString &engineName) const
+{
+ QString trimmed;
+ QString::ConstIterator constIter = engineName.constBegin();
+ while (constIter != engineName.constEnd())
+ {
+ if (constIter->isSpace())
+ {
+ trimmed.append('-');
+ }
+ else
+ {
+ if (*constIter != '.')
+ {
+ trimmed.append(constIter->toLower());
+ }
+ }
+ constIter++;
+ }
+
+ return trimmed;
+}
diff --git a/src/search/opensearchmanager.h b/src/search/opensearchmanager.h
new file mode 100644
index 00000000..8a45b83c
--- /dev/null
+++ b/src/search/opensearchmanager.h
@@ -0,0 +1,108 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+#ifndef OPENSEARCHMANAGER_H
+#define OPENSEARCHMANAGER_H
+
+
+// Rekonq Includes
+#include "rekonq_defines.h"
+
+// KDE Includes
+#include <kio/jobclasses.h>
+
+// Qt Includes
+#include <QtCore/QObject>
+
+// Forward Declarations
+class SuggestionEngine;
+class OpenSearchEngine;
+
+
+/**
+ * This class acts as a proxy between the SearchBar plugin
+ * and the individual suggestion engine.
+ * This class has a map of all available engines,
+ * and route the suggestion request to the correct engine.
+ */
+class OpenSearchManager : public QObject
+{
+ Q_OBJECT
+
+ enum STATE
+ {
+ REQ_SUGGESTION,
+ REQ_DESCRIPTION,
+ IDLE
+ };
+
+public:
+ /**
+ * Constructor
+ */
+ explicit OpenSearchManager(QObject *parent = 0);
+
+ virtual ~OpenSearchManager();
+
+ void setSearchProvider(const QString &searchProvider);
+
+ /**
+ * Check whether a search suggestion engine is available for the given search provider
+ * @param searchProvider the queried search provider
+ */
+ bool isSuggestionAvailable();
+
+ void addOpenSearchEngine(const KUrl &url, const QString &title);
+
+public slots:
+ /**
+ * Ask the specific suggestion engine to request for suggestion for the search text
+ * @param searchProvider the search provider that provides the suggestion service
+ * @param searchText the text to be queried to the suggestion service
+ */
+ void requestSuggestion(const QString &searchProvider);
+
+private slots:
+ void dataReceived(KIO::Job *job, const QByteArray &data);
+ void jobFinished(KJob *job);
+
+signals:
+ void suggestionReceived(const QStringList &suggestion);
+ void openSearchEngineAdded(const QString &name, const QString &searchUrl, const QString &fileName);
+
+private:
+ QString trimmedEngineName(const QString &engineName) const;
+
+ // QString substitutueSearchText(const QString &searchText, const QString &requestURL) const;
+ QByteArray m_jobData;
+ QMap<QString, OpenSearchEngine*> m_enginesMap;
+ OpenSearchEngine *m_activeEngine;
+ STATE m_state;
+};
+
+#endif // OPENSEARCHMANAGER_H
diff --git a/src/search/opensearchreader.cpp b/src/search/opensearchreader.cpp
new file mode 100644
index 00000000..5b7ece2c
--- /dev/null
+++ b/src/search/opensearchreader.cpp
@@ -0,0 +1,174 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+// Self Includes
+#include "opensearchreader.h"
+
+// Local Includes
+#include "opensearchengine.h"
+
+// Qt Includes
+#include <QtCore/QIODevice>
+
+
+OpenSearchReader::OpenSearchReader()
+ : QXmlStreamReader()
+{
+}
+
+
+OpenSearchEngine *OpenSearchReader::read(const QByteArray &data)
+{
+ clear();
+ addData(data);
+
+ return read();
+}
+
+
+OpenSearchEngine *OpenSearchReader::read(QIODevice *device)
+{
+ clear();
+
+ if (!device->isOpen())
+ {
+ device->open(QIODevice::ReadOnly);
+ }
+
+ setDevice(device);
+ return read();
+}
+
+
+OpenSearchEngine *OpenSearchReader::read()
+{
+ OpenSearchEngine *engine = new OpenSearchEngine();
+
+ while (!isStartElement() && !atEnd()) {
+ readNext();
+ }
+
+ if ( name() != QL1S("OpenSearchDescription")
+ || namespaceUri() != QL1S("http://a9.com/-/spec/opensearch/1.1/")
+ )
+ {
+ raiseError(QObject::tr("The file is not an OpenSearch 1.1 file."));
+ return engine;
+ }
+
+ while (!(isEndElement() && name() == QL1S("OpenSearchDescription")) && !atEnd())
+ {
+ readNext();
+
+ if (!isStartElement())
+ continue;
+
+ // ShortName
+ if (name() == QL1S("ShortName"))
+ {
+ engine->setName(readElementText());
+ continue;
+ }
+
+ // Description
+ if (name() == QL1S("Description"))
+ {
+ engine->setDescription(readElementText());
+ continue;
+ }
+
+ // Url
+ if (name() == QL1S("Url"))
+ {
+ QString type = attributes().value(QL1S("type")).toString();
+ QString url = attributes().value(QL1S("template")).toString();
+
+ if (url.isEmpty())
+ continue;
+
+ QList<OpenSearchEngine::Parameter> parameters;
+
+ readNext();
+
+ while (!(isEndElement() && name() == QL1S("Url")))
+ {
+ if (!isStartElement() || (name() != QL1S("Param") && name() != QL1S("Parameter"))) {
+ readNext();
+ continue;
+ }
+
+ QString key = attributes().value(QL1S("name")).toString();
+ QString value = attributes().value(QL1S("value")).toString();
+
+ if (!key.isEmpty() && !value.isEmpty())
+ {
+ parameters.append(OpenSearchEngine::Parameter(key, value));
+ }
+
+ while (!isEndElement())
+ {
+ readNext();
+ }
+ }
+
+ if (type == QL1S("application/x-suggestions+json"))
+ {
+ engine->setSuggestionsUrlTemplate(url);
+ engine->setSuggestionsParameters(parameters);
+ }
+ else
+ {
+ engine->setSearchUrlTemplate(url);
+ engine->setSearchParameters(parameters);
+ }
+
+ continue;
+ }
+
+ // Image
+ if (name() == QL1S("Image"))
+ {
+ engine->setImageUrl(readElementText());
+ continue;
+ }
+
+ // Engine check
+ if ( !engine->name().isEmpty()
+ && !engine->description().isEmpty()
+ && !engine->suggestionsUrlTemplate().isEmpty()
+ && !engine->searchUrlTemplate().isEmpty()
+ && !engine->imageUrl().isEmpty()
+ )
+ {
+ break;
+ }
+ }
+
+ return engine;
+}
diff --git a/src/search/opensearchreader.h b/src/search/opensearchreader.h
new file mode 100644
index 00000000..4e2444e0
--- /dev/null
+++ b/src/search/opensearchreader.h
@@ -0,0 +1,55 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+#ifndef OPENSEARCHREADER_H
+#define OPENSEARCHREADER_H
+
+
+// Rekonq Includes
+#include "rekonq_defines.h"
+
+// Qt Includes
+#include <QtCore/QXmlStreamReader>
+
+// Forward Declarations
+class OpenSearchEngine;
+
+
+class OpenSearchReader : public QXmlStreamReader
+{
+public:
+ OpenSearchReader();
+
+ OpenSearchEngine *read(const QByteArray &data);
+ OpenSearchEngine *read(QIODevice *device);
+
+private:
+ OpenSearchEngine *read();
+};
+
+#endif // OPENSEARCHREADER_H
diff --git a/src/search/opensearchwriter.cpp b/src/search/opensearchwriter.cpp
new file mode 100644
index 00000000..81ce022c
--- /dev/null
+++ b/src/search/opensearchwriter.cpp
@@ -0,0 +1,134 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+// Self Includes
+#include "opensearchwriter.h"
+
+// Local Includes
+#include "opensearchengine.h"
+
+// KDE Includes
+#include <KDebug>
+
+// Qt Includes
+#include <QtCore/QIODevice>
+
+
+
+OpenSearchWriter::OpenSearchWriter()
+ : QXmlStreamWriter()
+{
+ setAutoFormatting(true);
+}
+
+
+bool OpenSearchWriter::write(QIODevice *device, OpenSearchEngine *engine)
+{
+ if (!engine)
+ return false;
+
+ if (!device->isOpen())
+ device->open(QIODevice::WriteOnly);
+
+ setDevice(device);
+ write(engine);
+ return true;
+}
+
+
+void OpenSearchWriter::write(OpenSearchEngine *engine)
+{
+ writeStartDocument();
+ writeStartElement(QL1S("OpenSearchDescription"));
+ writeDefaultNamespace(QL1S("http://a9.com/-/spec/opensearch/1.1/"));
+
+ if (!engine->name().isEmpty())
+ {
+ writeTextElement(QL1S("ShortName"), engine->name());
+ }
+
+ if (!engine->description().isEmpty())
+ {
+ writeTextElement(QL1S("Description"), engine->description());
+ }
+
+ if (!engine->searchUrlTemplate().isEmpty())
+ {
+ writeStartElement(QL1S("Url"));
+ writeAttribute(QL1S("method"), QL1S("get"));
+ writeAttribute(QL1S("template"), engine->searchUrlTemplate());
+
+ if (!engine->searchParameters().empty())
+ {
+ writeNamespace(QL1S("http://a9.com/-/spec/opensearch/extensions/parameters/1.0/"), QL1S("p"));
+
+ QList<OpenSearchEngine::Parameter>::const_iterator end = engine->searchParameters().constEnd();
+ QList<OpenSearchEngine::Parameter>::const_iterator i = engine->searchParameters().constBegin();
+ for (; i != end; ++i)
+ {
+ writeStartElement(QL1S("p:Parameter"));
+ writeAttribute(QL1S("name"), i->first);
+ writeAttribute(QL1S("value"), i->second);
+ writeEndElement();
+ }
+ }
+
+ writeEndElement();
+ }
+
+ if (!engine->suggestionsUrlTemplate().isEmpty())
+ {
+ writeStartElement(QL1S("Url"));
+ writeAttribute(QL1S("method"), QL1S("get"));
+ writeAttribute(QL1S("type"), QL1S("application/x-suggestions+json"));
+ writeAttribute(QL1S("template"), engine->suggestionsUrlTemplate());
+
+ if (!engine->suggestionsParameters().empty())
+ {
+ writeNamespace(QL1S("http://a9.com/-/spec/opensearch/extensions/parameters/1.0/"), QL1S("p"));
+
+ QList<OpenSearchEngine::Parameter>::const_iterator end = engine->suggestionsParameters().constEnd();
+ QList<OpenSearchEngine::Parameter>::const_iterator i = engine->suggestionsParameters().constBegin();
+ for (; i != end; ++i)
+ {
+ writeStartElement(QL1S("p:Parameter"));
+ writeAttribute(QL1S("name"), i->first);
+ writeAttribute(QL1S("value"), i->second);
+ writeEndElement();
+ }
+ }
+
+ writeEndElement();
+ }
+
+ if (!engine->imageUrl().isEmpty())
+ writeTextElement(QL1S("Image"), engine->imageUrl());
+
+ writeEndElement();
+ writeEndDocument();
+}
diff --git a/src/search/opensearchwriter.h b/src/search/opensearchwriter.h
new file mode 100644
index 00000000..6a2e0d11
--- /dev/null
+++ b/src/search/opensearchwriter.h
@@ -0,0 +1,56 @@
+/* ============================================================
+*
+* This file is a part of the rekonq project
+*
+* Copyright (C) 2009 by Jakub Wieczorek <faw217@gmail.com>
+* Copyright (C) 2010 by Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2010 by Andrea Diamantini <adjam7 at gmail dot com>
+*
+*
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU General Public License as
+* published by the Free Software Foundation; either version 2 of
+* the License or (at your option) version 3 or any later version
+* accepted by the membership of KDE e.V. (or its successor approved
+* by the membership of KDE e.V.), which shall act as a proxy
+* defined in Section 14 of version 3 of the license.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program. If not, see <http://www.gnu.org/licenses/>.
+*
+* ============================================================ */
+
+
+#ifndef OPENSEARCHWRITER_H
+#define OPENSEARCHWRITER_H
+
+
+// Rekonq Includes
+#include "rekonq_defines.h"
+
+// Qt Includes
+#include <QtCore/QXmlStreamWriter>
+
+// Forward Declarations
+class QIODevice;
+class OpenSearchEngine;
+
+
+class OpenSearchWriter : public QXmlStreamWriter
+{
+public:
+ OpenSearchWriter();
+
+ bool write(QIODevice *device, OpenSearchEngine *engine);
+
+private:
+ void write(OpenSearchEngine *engine);
+};
+
+#endif
+
diff --git a/src/searchengine.cpp b/src/search/searchengine.cpp
index 7065d55f..7065d55f 100644
--- a/src/searchengine.cpp
+++ b/src/search/searchengine.cpp
diff --git a/src/searchengine.h b/src/search/searchengine.h
index e57b1a5c..e57b1a5c 100644
--- a/src/searchengine.h
+++ b/src/search/searchengine.h
diff --git a/src/settings/appearancewidget.cpp b/src/settings/appearancewidget.cpp
index 03d81808..c444f724 100644
--- a/src/settings/appearancewidget.cpp
+++ b/src/settings/appearancewidget.cpp
@@ -87,4 +87,4 @@ bool AppearanceWidget::isDefault()
// TODO: implement me!!
return def;
-} \ No newline at end of file
+}
diff --git a/src/tabbar.cpp b/src/tabbar.cpp
index 2d29032f..98243e71 100644
--- a/src/tabbar.cpp
+++ b/src/tabbar.cpp
@@ -322,6 +322,12 @@ void TabBar::emptyAreaContextMenu(const QPoint &pos)
menu.addSeparator();
menu.addAction(mainWindow->actionByName( QL1S("reload_all_tabs") ));
+ KToolBar *mainBar = mainWindow->toolBar("mainToolBar");
+ if(!mainBar->isVisible())
+ {
+ menu.addAction( mainBar->toggleViewAction() );
+ }
+
menu.exec(pos);
}
diff --git a/src/urlbar/bookmarkwidget.cpp b/src/urlbar/bookmarkwidget.cpp
index bcf85e1f..0e05e776 100644
--- a/src/urlbar/bookmarkwidget.cpp
+++ b/src/urlbar/bookmarkwidget.cpp
@@ -30,7 +30,7 @@
// Local includes
#include "application.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "bookmarkowner.h"
// KDE Includes
diff --git a/src/urlbar/bookmarkwidget.h b/src/urlbar/bookmarkwidget.h
index cdab328e..c3c15e18 100644
--- a/src/urlbar/bookmarkwidget.h
+++ b/src/urlbar/bookmarkwidget.h
@@ -44,7 +44,7 @@ class BookmarkWidget : public QFrame
Q_OBJECT
public:
- BookmarkWidget(const KBookmark &bookmark, QWidget *parent = 0);
+ explicit BookmarkWidget(const KBookmark &bookmark, QWidget *parent = 0);
~BookmarkWidget();
void showAt(const QPoint &pos);
diff --git a/src/urlbar/completionwidget.cpp b/src/urlbar/completionwidget.cpp
index b77e2d7c..a9203bf7 100644
--- a/src/urlbar/completionwidget.cpp
+++ b/src/urlbar/completionwidget.cpp
@@ -153,13 +153,10 @@ void CompletionWidget::activateCurrentListItem()
//update text of the url bar
bar->blockSignals(true); //without compute suggestions
- if (!widget->inherits("SearchListItem"))
- bar->setQUrl( widget->url() );
- else
- bar->setQUrl( _typedString );
+ bar->setQUrl(widget->text());
bar->blockSignals(false);
bar->setFocus();
- bar->setCursorPosition( bar->text().length() );
+ bar->setCursorPosition(bar->text().length());
}
@@ -240,7 +237,7 @@ bool CompletionWidget::eventFilter(QObject *obj, QEvent *ev)
if( _currentIndex == -1)
_currentIndex = 0;
child = findChild<ListItem *>(QString::number(_currentIndex));
- if(child && _typedString == w->text())
+ if(child)
{
emit chosenUrl(child->url(), Rekonq::CurrentTab);
}
diff --git a/src/urlbar/listitem.cpp b/src/urlbar/listitem.cpp
index f10cefd7..e9bb6fbb 100644
--- a/src/urlbar/listitem.cpp
+++ b/src/urlbar/listitem.cpp
@@ -139,6 +139,12 @@ KUrl ListItem::url()
}
+QString ListItem::text()
+{
+ return m_url.url();
+}
+
+
void ListItem::nextItemSubChoice()
{
//will be override
@@ -161,6 +167,7 @@ TypeIconLabel::TypeIconLabel(int type, QWidget *parent)
if (type & UrlSearchItem::Browse) hLayout->addWidget(getIcon("applications-internet"));
if (type & UrlSearchItem::Bookmark) hLayout->addWidget(getIcon("rating"));
if (type & UrlSearchItem::History) hLayout->addWidget(getIcon("view-history"));
+ if (type & UrlSearchItem::Suggestion) hLayout->addWidget(getIcon("help-hint"));
}
@@ -297,6 +304,12 @@ SearchListItem::SearchListItem(const UrlSearchItem &item, const QString &text, Q
}
+QString SearchListItem::text()
+{
+ return m_text;
+}
+
+
QString SearchListItem::searchItemTitle(QString engine, QString text)
{
return QString(i18nc("%1=search engine, e.g. Google, Wikipedia %2=text to search for", "Search %1 for <b>%2</b>", engine, Qt::escape(text)));
@@ -390,6 +403,42 @@ void EngineBar::selectNextEngine()
// ---------------------------------------------------------------
+SuggestionListItem::SuggestionListItem(const UrlSearchItem &item, const QString &text, QWidget *parent)
+ : ListItem(item, parent)
+ , m_text(item.title)
+{
+ QHBoxLayout *hLayout = new QHBoxLayout;
+ hLayout->setSpacing(4);
+
+ QString query = item.title;
+ KService::Ptr engine = SearchEngine::fromString(query);
+ if (engine)
+ {
+ query = query.remove(0, text.indexOf(SearchEngine::delimiter()) + 1);
+ }
+ else
+ {
+ engine = qobject_cast<CompletionWidget *>(parent)->searchEngine();
+ }
+
+ m_url = SearchEngine::buildQuery(engine, query);
+
+ hLayout->addWidget(new IconLabel(SearchEngine::buildQuery(engine, ""), this));
+ hLayout->addWidget(new TextLabel(item.title, text, this));
+ hLayout->addWidget(new TypeIconLabel(item.type, this));
+
+ setLayout(hLayout);
+}
+
+
+QString SuggestionListItem::text()
+{
+ return m_text;
+}
+
+// ---------------------------------------------------------------
+
+
BrowseListItem::BrowseListItem(const UrlSearchItem &item, const QString &text, QWidget *parent)
: ListItem(item, parent)
{
@@ -427,7 +476,15 @@ ListItem *ListItemFactory::create(const UrlSearchItem &item, const QString &text
}
else
{
- newItem = new PreviewListItem(item, text, parent);
+
+ if (item.type & UrlSearchItem::Suggestion)
+ {
+ newItem = new SuggestionListItem(item, text, parent);
+ }
+ else
+ {
+ newItem = new PreviewListItem(item, text, parent);
+ }
}
}
diff --git a/src/urlbar/listitem.h b/src/urlbar/listitem.h
index dcb4f76d..06a02b80 100644
--- a/src/urlbar/listitem.h
+++ b/src/urlbar/listitem.h
@@ -61,7 +61,8 @@ public:
void deactivate();
KUrl url();
-
+ virtual QString text();
+
public slots:
virtual void nextItemSubChoice();
@@ -153,6 +154,7 @@ class SearchListItem : public ListItem
public:
explicit SearchListItem(const UrlSearchItem &item, const QString &text, QWidget *parent = 0);
+ QString text();
public slots:
virtual void nextItemSubChoice();
@@ -174,6 +176,22 @@ private:
// -------------------------------------------------------------------------
+class SuggestionListItem : public ListItem
+{
+ Q_OBJECT
+
+public:
+ SuggestionListItem(const UrlSearchItem &item, const QString &text, QWidget *parent = 0);
+ QString text();
+
+private:
+ QString m_text;
+};
+
+
+// -------------------------------------------------------------------------
+
+
class PreviewListItem : public ListItem
{
Q_OBJECT
diff --git a/src/urlbar/urlbar.cpp b/src/urlbar/urlbar.cpp
index e64959bd..c272d819 100644
--- a/src/urlbar/urlbar.cpp
+++ b/src/urlbar/urlbar.cpp
@@ -41,10 +41,11 @@
#include "webpage.h"
#include "webview.h"
#include "completionwidget.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "bookmarkwidget.h"
// KDE Includes
+#include <KBookmarkManager>
#include <KCompletionBox>
#include <KStandardDirs>
@@ -105,7 +106,7 @@ UrlBar::UrlBar(QWidget *parent)
_tab = qobject_cast<WebTab *>(parent);
connect(_tab, SIGNAL(loadProgressing()), this, SLOT(update()));
-
+
connect(_tab->view(), SIGNAL(urlChanged(const QUrl &)), this, SLOT(setQUrl(const QUrl &)));
connect(_tab->view(), SIGNAL(loadFinished(bool)), this, SLOT(loadFinished()));
connect(_tab->view(), SIGNAL(loadStarted()), this, SLOT(clearRightIcons()));
@@ -114,13 +115,13 @@ UrlBar::UrlBar(QWidget *parent)
_icon->setIcon(KIcon("bookmarks").pixmap(32,32, QIcon::Disabled));
connect(Application::bookmarkProvider()->bookmarkManager(), SIGNAL(changed(const QString &, const QString &)), this, SLOT(onBookmarksChanged()));
connect(_icon, SIGNAL(clicked(const QPoint &)), this, SLOT(showBookmarkInfo(const QPoint &)));
-
+
// load typed urls
connect(this, SIGNAL(returnPressed(const QString &)), this, SLOT(loadTyped(const QString &)));
_suggestionTimer->setSingleShot(true);
connect(_suggestionTimer, SIGNAL(timeout()), this, SLOT(suggest()));
-
+
activateSuggestions(true);
}
@@ -163,10 +164,10 @@ void UrlBar::activated(const KUrl& url, Rekonq::OpenType type)
void UrlBar::paintEvent(QPaintEvent *event)
-{
+{
QColor backgroundColor;
QColor foregroundColor;
-
+
if (_privateMode)
{
backgroundColor = QColor(220, 220, 220); // light gray
@@ -199,7 +200,7 @@ void UrlBar::paintEvent(QPaintEvent *event)
int r = (highlight.red()+2*backgroundColor.red())/3;
int g = (highlight.green()+2*backgroundColor.green())/3;
int b = (highlight.blue()+2*backgroundColor.blue())/3;
-
+
QColor loadingColor(r, g, b);
if (abs(loadingColor.lightness() - backgroundColor.lightness()) < 20) //eg. Gaia color scheme
@@ -320,7 +321,7 @@ void UrlBar::loadFinished()
_icon->setIcon(KIcon("bookmarks"));
_icon->setToolTip(i18n("Edit this bookmark"));
}
-
+
// show KGet downloads??
if (!KStandardDirs::findExe("kget").isNull() && ReKonfig::kgetList())
{
@@ -343,7 +344,7 @@ void UrlBar::loadFinished()
}
// we need to update urlbar after the right icon settings
- // removing this code (where setStyleSheet automatically calls update) needs adding again
+ // removing this code (where setStyleSheet automatically calls update) needs adding again
// an update call
kDebug() << "resetting stylesheet";
int rightIconWidth = 25 * (_rightIconsList.count());
@@ -355,7 +356,7 @@ void UrlBar::showBookmarkInfo(const QPoint &pos)
{
if( _tab->url().scheme() == QL1S("about") )
return;
-
+
KBookmark bookmark = Application::bookmarkProvider()->bookmarkForUrl(_tab->url());
IconButton *bt = qobject_cast<IconButton *>(this->sender());
@@ -367,7 +368,7 @@ void UrlBar::showBookmarkInfo(const QPoint &pos)
bookmark = Application::bookmarkProvider()->rootGroup().addBookmark(_tab->view()->title(), _tab->url());
Application::bookmarkProvider()->bookmarkManager()->emitChanged();
}
-
+
BookmarkWidget *widget = new BookmarkWidget(bookmark, window());
widget->showAt(pos);
}
@@ -480,7 +481,7 @@ void UrlBar::detectTypedString(const QString &typed)
QTimer::singleShot(0, this, SLOT(suggest()));
return;
}
-
+
if(_suggestionTimer->isActive())
_suggestionTimer->stop();
_suggestionTimer->start(50);
diff --git a/src/urlbar/urlresolver.cpp b/src/urlbar/urlresolver.cpp
index b762716a..d60dc563 100644
--- a/src/urlbar/urlresolver.cpp
+++ b/src/urlbar/urlresolver.cpp
@@ -30,10 +30,11 @@
// Local Includes
#include "application.h"
#include "historymanager.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "searchengine.h"
// KDE Includes
+#include <KBookmark>
#include <KUriFilter>
#include <KCompletion>
#include <KService>
@@ -45,9 +46,9 @@
// defines
#define MAX_ELEMENTS 10
+#define MIN_SUGGESTIONS 3
-
-// NOTE
+// NOTE
// default kurifilter plugin list (at least in my box):
// 1. "kshorturifilter"
// 2. "kurisearchfilter"
@@ -63,23 +64,24 @@ QRegExp UrlResolver::_browseRegexp;
QRegExp UrlResolver::_searchEnginesRegexp;
UrlResolver::UrlResolver(const QString &typedUrl)
- : _typedString(typedUrl.trimmed())
+ : QObject()
+ , _typedString(typedUrl.trimmed())
{
if ( _browseRegexp.isEmpty() )
{
kDebug() << "browse regexp empty. Setting value..";
-
+
QString protocol = "^(http://|https://|file://|ftp://|man:|info:|apt:)";
-
+
QString localhost = "^localhost";
-
+
QString local = "^/";
-
+
QString ipv4 = "^0*([1-9]?\\d|1\\d\\d|2[0-4]\\d|25[0-5])\\.0*([1-9]?\\d|1\\d\\d|2[0-4]\\d|25[0-5])"\
"\\.0*([1-9]?\\d|1\\d\\d|2[0-4]\\d|25[0-5])\\.0*([1-9]?\\d|1\\d\\d|2[0-4]\\d|25[0-5])";
-
+
QString ipv6 = "^([0-9a-fA-F]{4}|0)(\\:([0-9a-fA-F]{4}|0)){7}";
-
+
QString address = "[\\d\\w-.]+\\.(a[cdefgilmnoqrstuwz]|b[abdefghijmnorstvwyz]|"\
"c[acdfghiklmnoruvxyz]|d[ejkmnoz]|e[ceghrst]|f[ijkmnor]|g[abdefghilmnpqrstuwy]|"\
"h[kmnrtu]|i[delmnoqrst]|j[emop]|k[eghimnprwyz]|l[abcikrstuvy]|"\
@@ -87,19 +89,21 @@ UrlResolver::UrlResolver(const QString &typedUrl)
"s[abcdeghijklmnortuvyz]|t[cdfghjkmnoprtvwz]|u[augkmsyz]|v[aceginu]|w[fs]|"\
"y[etu]|z[amw]|aero|arpa|biz|com|coop|edu|info|int|gov|mil|museum|name|net|org|"\
"pro)";
-
+
_browseRegexp = QRegExp('(' + protocol + ")|(" + localhost + ")|(" + local + ")|(" + address + ")|(" + ipv6 + ")|(" + ipv4 +')');
}
-
+
if ( _searchEnginesRegexp.isEmpty() )
{
QString reg;
QString engineUrl;
- foreach(KService::Ptr s, SearchEngine::favorites())
+ Q_FOREACH(KService::Ptr s, SearchEngine::favorites())
{
engineUrl = QRegExp::escape(s->property("Query").toString()).replace("\\\\\\{@\\}","[\\d\\w-.]+");
- if (reg.isEmpty()) reg = "(" + engineUrl + ")";
- else reg = reg + "|(" + engineUrl + ")";
+ if (reg.isEmpty())
+ reg = '(' + engineUrl + ')';
+ else
+ reg = reg + "|(" + engineUrl + ')';
}
_searchEnginesRegexp = QRegExp(reg);
}
@@ -108,20 +112,9 @@ UrlResolver::UrlResolver(const QString &typedUrl)
UrlSearchList UrlResolver::orderedSearchItems()
{
- // NOTE
- // the logic here is : "we wanna suggest (at least) 10 elements"
- // so we have (more or less) 2 from first results (1 from QUrl Resolutions, 1 from
- // search engines).
- // There are 8 remaining: if bookmarkResults + historyResults <= 8, catch all, else
- // catch first 4 results from the two resulting lists :)
-
- QTime myTime;
- myTime.start();
-
- UrlSearchList list;
-
if( _typedString == QL1S("about:") )
{
+ UrlSearchList list;
UrlSearchItem home(UrlSearchItem::Browse, QString("about:home"), QL1S("home") );
list << home;
UrlSearchItem favs(UrlSearchItem::Browse, QString("about:favorites"), QL1S("favorites") );
@@ -137,147 +130,188 @@ UrlSearchList UrlResolver::orderedSearchItems()
return list;
}
-
+
+ _computedListsCount = 0;
+
+ //compute lists
+ computeSuggestions();
+ computeQurlFromUserInput();
+ computeWebSearches();
+ computeBookmarks();
+ computeHistory();
+
+ QTime time;
+ time.start();
+
+ while (_computedListsCount < 5 && time.msec() < 1000)
+ {
+ Application::instance()->processEvents(QEventLoop::WaitForMoreEvents | QEventLoop::ExcludeUserInputEvents);
+ }
+
+ return orderLists();
+}
+
+
+UrlSearchList UrlResolver::orderLists()
+{
+ // NOTE
+ // the logic here is : "we wanna suggest (at least) 10 elements"
+ // so we have (more or less) 2 from first results (1 from QUrl Resolutions, 1 from
+ // search engines).
+ // There are 8 remaining: if bookmarkResults + historyResults <= 8, catch all, else
+ // catch first 4 results from the two resulting lists :)
+
+ QTime myTime;
+ myTime.start();
+
+ UrlSearchList list;
+
if(_browseRegexp.indexIn(_typedString) != -1)
{
- list << qurlFromUserInputResolution();
- list << webSearchesResolution();
+ list << _qurlFromUserInput;
+ list << _webSearches;
}
else
{
- list << webSearchesResolution();
- list << qurlFromUserInputResolution();
+ list << _webSearches;
+ list << _qurlFromUserInput;
}
//find the history items that match the typed string
- UrlSearchList historyList = historyResolution();
- UrlSearchItem privileged = privilegedItem(&historyList);
- int historyResults = historyList.count();
-
+ UrlSearchItem privileged = privilegedItem(&_history);
+ int historyCount = _history.count();
+
//find the bookmarks items that match the typed string
- UrlSearchList bookmarksList = bookmarksResolution();
if (privileged.type == UrlSearchItem::Undefined)
{
- privileged = privilegedItem(&bookmarksList);
+ privileged = privilegedItem(&_bookmarks);
}
- else if(privileged.type == UrlSearchItem::History && bookmarksList.removeOne(privileged))
+ else if(privileged.type == UrlSearchItem::History && _bookmarks.removeOne(privileged))
{
privileged.type |= UrlSearchItem::Bookmark;
}
- int bookmarksResults = bookmarksList.count();
-
+ int bookmarksCount = _bookmarks.count();
+
if (privileged.type != UrlSearchItem::Undefined)
{
list.prepend(privileged);
}
-
- int availableEntries = MAX_ELEMENTS - list.count();
-
- UrlSearchList commonList;
- int commonResutls = 0;
+
+ int availableEntries = MAX_ELEMENTS - list.count() - MIN_SUGGESTIONS;
+
+ UrlSearchList common;
+ int commonCount = 0;
//prefer items which are history items als well bookmarks item
//if there are more than 1000 bookmark results, the performance impact is noticeable
- if(bookmarksResults < 1000)
+ if(bookmarksCount < 1000)
{
//add as many items to the common list as there are available entries in the dropdown list
UrlSearchItem urlSearchItem;
- for(int i = 0; i < historyList.count(); i++)
+ for(int i = 0; i < _history.count(); i++)
{
- if (bookmarksList.removeOne(historyList.at(i)))
+ if (_bookmarks.removeOne(_history.at(i)))
{
- urlSearchItem = historyList.takeAt(i);
+ urlSearchItem = _history.takeAt(i);
urlSearchItem.type |= UrlSearchItem::Bookmark;
- commonList << urlSearchItem;
- commonResutls++;
- if(commonResutls >= availableEntries)
+ common << urlSearchItem;
+ commonCount++;
+ if(commonCount >= availableEntries)
{
break;
}
}
}
-
- commonResutls = commonList.count();
- if(commonResutls >= availableEntries)
+
+ commonCount = common.count();
+ if(commonCount >= availableEntries)
{
- commonList = commonList.mid(0, availableEntries);
- historyList = UrlSearchList();
- bookmarksList = UrlSearchList();
+ common = common.mid(0, availableEntries);
+ _history = UrlSearchList();
+ _bookmarks = UrlSearchList();
availableEntries = 0;
}
else //remove all items from the history and bookmarks list up to the remaining entries in the dropdown list
{
- availableEntries -= commonResutls;
- if(historyResults >= availableEntries)
+ availableEntries -= commonCount;
+ if(historyCount >= availableEntries)
{
- historyList = historyList.mid(0, availableEntries);
+ _history = _history.mid(0, availableEntries);
}
- if(bookmarksResults >= availableEntries)
+ if(bookmarksCount >= availableEntries)
{
- bookmarksList = bookmarksList.mid(0, availableEntries);
+ _bookmarks = _bookmarks.mid(0, availableEntries);
}
}
}
else //if there are too many bookmarks items, remove all items up to the remaining entries in the dropdown list
{
-
- if(historyResults >= availableEntries)
+
+ if(historyCount >= availableEntries)
{
- historyList = historyList.mid(0, availableEntries);
+ _history = _history.mid(0, availableEntries);
}
- if(bookmarksResults >= availableEntries)
+ if(bookmarksCount >= availableEntries)
{
- bookmarksList = bookmarksList.mid(0, availableEntries);
+ _bookmarks = _bookmarks.mid(0, availableEntries);
}
UrlSearchItem urlSearchItem;
- for(int i = 0; i < historyList.count(); i++)
+ for(int i = 0; i < _history.count(); i++)
{
- if (bookmarksList.removeOne(historyList.at(i)))
+ if (_bookmarks.removeOne(_history.at(i)))
{
- urlSearchItem = historyList.takeAt(i);
+ urlSearchItem = _history.takeAt(i);
urlSearchItem.type |= UrlSearchItem::Bookmark;
- commonList << urlSearchItem;
+ common << urlSearchItem;
}
}
-
- availableEntries -= commonList.count();
+
+ availableEntries -= common.count();
}
-
- historyResults = historyList.count();
- bookmarksResults = bookmarksList.count();
- commonResutls = commonList.count();
-
+
+ historyCount = _history.count();
+ bookmarksCount = _bookmarks.count();
+ commonCount = common.count();
+
//now fill the list to MAX_ELEMENTS
if(availableEntries > 0)
{
int historyEntries = ((int) (availableEntries / 2)) + availableEntries % 2;
int bookmarksEntries = availableEntries - historyEntries;
-
- if (historyResults >= historyEntries && bookmarksResults >= bookmarksEntries)
+
+ if (historyCount >= historyEntries && bookmarksCount >= bookmarksEntries)
{
- historyList = historyList.mid(0, historyEntries);
- bookmarksList = bookmarksList.mid(0, bookmarksEntries);
+ _history = _history.mid(0, historyEntries);
+ _bookmarks = _bookmarks.mid(0, bookmarksEntries);
}
- else if (historyResults < historyEntries && bookmarksResults >= bookmarksEntries)
+ else if (historyCount < historyEntries && bookmarksCount >= bookmarksEntries)
{
- if(historyResults + bookmarksResults > availableEntries)
+ if(historyCount + bookmarksCount > availableEntries)
{
- bookmarksList = bookmarksList.mid(0, availableEntries - historyResults);
+ _bookmarks = _bookmarks.mid(0, availableEntries - historyCount);
}
}
- else if (historyResults >= historyEntries && bookmarksResults < bookmarksEntries)
+ else if (historyCount >= historyEntries && bookmarksCount < bookmarksEntries)
{
- if(historyResults + bookmarksResults > availableEntries)
+ if(historyCount + bookmarksCount > availableEntries)
{
- historyList = historyList.mid(0, availableEntries - bookmarksResults);
+ _history = _history.mid(0, availableEntries - bookmarksCount);
}
}
}
-
- list = list + historyList + commonList + bookmarksList;
+
+ availableEntries -= _history.count();
+ availableEntries -= _bookmarks.count();
+
+ if (_suggestions.count() > availableEntries + MIN_SUGGESTIONS)
+ {
+ _suggestions = _suggestions.mid(0, availableEntries + MIN_SUGGESTIONS);
+ }
+
+ list = list + _history + common + _bookmarks + _suggestions;
qWarning() << "orderedSearchItems leave: " << " elapsed: " << myTime.elapsed();
-
+
return list;
}
@@ -286,70 +320,103 @@ UrlSearchList UrlResolver::orderedSearchItems()
// PRIVATE ENGINES
-// STEP 1 = QUrl from User Input (easily the best solution... )
-UrlSearchList UrlResolver::qurlFromUserInputResolution()
+//QUrl from User Input (easily the best solution... )
+void UrlResolver::computeQurlFromUserInput()
{
- UrlSearchList list;
- QString url2 = _typedString;
- QUrl urlFromUserInput = QUrl::fromUserInput(url2);
+ QString url = _typedString;
+ QUrl urlFromUserInput = QUrl::fromUserInput(url);
if (urlFromUserInput.isValid())
{
QString gTitle = i18nc("Browse a website", "Browse");
UrlSearchItem gItem(UrlSearchItem::Browse, urlFromUserInput.toString(), gTitle);
- list << gItem;
+ _qurlFromUserInput << gItem;
}
- return list;
+ _computedListsCount++;
}
-// STEP 2 = Web Searches
-UrlSearchList UrlResolver::webSearchesResolution()
+//webSearches
+void UrlResolver::computeWebSearches()
{
- return UrlSearchList() << UrlSearchItem(UrlSearchItem::Search, QString(), QString());
+ _webSearches = (UrlSearchList() << UrlSearchItem(UrlSearchItem::Search, QString(), QString()));
+ _computedListsCount++;
}
-// STEP 3 = history completion
-UrlSearchList UrlResolver::historyResolution()
+//history
+void UrlResolver::computeHistory()
{
QList<HistoryItem> found = Application::historyManager()->find(_typedString);
qSort(found);
- UrlSearchList list;
- foreach (HistoryItem i, found)
+ Q_FOREACH(const HistoryItem &i, found)
{
if (_searchEnginesRegexp.indexIn(i.url) == -1) //filter all urls that are search engine results
{
UrlSearchItem gItem(UrlSearchItem::History, i.url, i.title);
- list << gItem;
+ _history << gItem;
}
}
- return list;
+
+ _computedListsCount++;
}
-// STEP 4 = bookmarks completion
-UrlSearchList UrlResolver::bookmarksResolution()
+// bookmarks
+void UrlResolver::computeBookmarks()
{
- UrlSearchList list;
QList<KBookmark> found = Application::bookmarkProvider()->find(_typedString);
- foreach (KBookmark b, found)
+
+ Q_FOREACH(const KBookmark &b, found)
{
UrlSearchItem gItem(UrlSearchItem::Bookmark, b.url().url(), b.fullText());
- list << gItem;
+ _bookmarks << gItem;
}
- return list;
+
+ _computedListsCount++;
+}
+
+
+//opensearch suggestion
+void UrlResolver::computeSuggestions()
+{
+ if (Application::opensearchManager()->isSuggestionAvailable())
+ {
+ connect(Application::opensearchManager(),
+ SIGNAL(suggestionReceived(const QStringList &)),
+ this,
+ SLOT(suggestionsReceived(const QStringList &)));
+
+ Application::opensearchManager()->requestSuggestion(_typedString);
+ }
+ else
+ {
+ _computedListsCount++;
+ }
+}
+
+
+void UrlResolver::suggestionsReceived(const QStringList &suggestion)
+{
+
+ foreach (QString s, suggestion)
+ {
+ UrlSearchItem gItem(UrlSearchItem::Suggestion, s, s);
+ _suggestions << gItem;
+ }
+
+ _computedListsCount++;
}
UrlSearchItem UrlResolver::privilegedItem(UrlSearchList* list)
{
UrlSearchItem item;
- QString dot = QString(QL1C('.'));
+ QString dot = QString(QL1C('.'));
QString test1 = QString(QL1C('/')) + _typedString + dot;
QString test2 = dot + _typedString + dot;
-
+
for(int i = 0; i<list->count(); i++)
{
item = list->at(i);
diff --git a/src/urlbar/urlresolver.h b/src/urlbar/urlresolver.h
index c79ce184..f72d6731 100644
--- a/src/urlbar/urlresolver.h
+++ b/src/urlbar/urlresolver.h
@@ -38,6 +38,7 @@
// Qt Includes
#include <QString>
#include <QList>
+#include <QStringList>
class UrlSearchItem
{
@@ -50,6 +51,7 @@ public:
Browse = 0x00000010,
History = 0x00000100,
Bookmark = 0x00001000,
+ Suggestion = 0x00010000,
};
int type;
@@ -93,8 +95,10 @@ typedef QList <UrlSearchItem> UrlSearchList;
// ----------------------------------------------------------------------
-class UrlResolver
+class UrlResolver : public QObject
{
+ Q_OBJECT
+
public:
UrlResolver(const QString &typedUrl);
@@ -103,14 +107,29 @@ public:
private:
QString _typedString;
- UrlSearchList webSearchesResolution();
- UrlSearchList historyResolution();
- UrlSearchList qurlFromUserInputResolution();
- UrlSearchList bookmarksResolution();
+ UrlSearchList _webSearches;
+ UrlSearchList _qurlFromUserInput;
+ UrlSearchList _history;
+ UrlSearchList _bookmarks;
+ UrlSearchList _suggestions;
+
+ void computeWebSearches();
+ void computeHistory();
+ void computeQurlFromUserInput();
+ void computeBookmarks();
+ void computeSuggestions();
+
+ int _computedListsCount;
+
UrlSearchItem privilegedItem(UrlSearchList* list);
-
+ UrlSearchList orderLists();
+
static QRegExp _browseRegexp;
static QRegExp _searchEnginesRegexp;
+
+private slots:
+ void suggestionsReceived(const QStringList &suggestion);
+
};
// ------------------------------------------------------------------------------
diff --git a/src/webpage.cpp b/src/webpage.cpp
index 8221626e..9167c96d 100644
--- a/src/webpage.cpp
+++ b/src/webpage.cpp
@@ -125,12 +125,20 @@ static bool downloadResource (const KUrl& srcUrl, const KIO::MetaData& metaData
if (finfo.exists())
{
QDateTime now = QDateTime::currentDateTime();
- KIO::RenameDialog dlg (parent, i18n("Overwrite File?"), srcUrl, destUrl,
- KIO::RenameDialog_Mode(KIO::M_OVERWRITE | KIO::M_SKIP),
- -1, finfo.size(),
- now.toTime_t(), finfo.created().toTime_t(),
- now.toTime_t(), finfo.lastModified().toTime_t());
- result = dlg.exec();
+ QPointer<KIO::RenameDialog> dlg = new KIO::RenameDialog( parent,
+ i18n("Overwrite File?"),
+ srcUrl,
+ destUrl,
+ KIO::RenameDialog_Mode(KIO::M_OVERWRITE | KIO::M_SKIP),
+ -1,
+ finfo.size(),
+ now.toTime_t(),
+ finfo.created().toTime_t(),
+ now.toTime_t(),
+ finfo.lastModified().toTime_t()
+ );
+ result = dlg->exec();
+ delete dlg;
}
}
}
diff --git a/src/webtab.cpp b/src/webtab.cpp
index 9e168d36..0b58d7c5 100644
--- a/src/webtab.cpp
+++ b/src/webtab.cpp
@@ -36,7 +36,7 @@
#include "application.h"
#include "mainwindow.h"
#include "mainview.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "walletbar.h"
#include "previewselectorbar.h"
#include "rsswidget.h"
@@ -66,7 +66,7 @@ WebTab::WebTab(QWidget *parent)
, m_progress(0)
{
setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-
+
QVBoxLayout *l = new QVBoxLayout(this);
l->setMargin(0);
l->setSpacing(0);
@@ -158,7 +158,7 @@ void WebTab::createPreviewSelectorBar(int index)
{
PreviewSelectorBar *bar = new PreviewSelectorBar(index, this);
qobject_cast<QVBoxLayout *>(layout())->insertWidget(0, bar);
-
+
connect(page(), SIGNAL(loadStarted()), bar, SLOT(loadProgress()));
connect(page(), SIGNAL(loadProgress(int)), bar, SLOT(loadProgress()));
connect(page(), SIGNAL(loadFinished(bool)), bar, SLOT(loadFinished()));
@@ -183,7 +183,7 @@ void WebTab::showRSSInfo(QPoint pos)
col.append(page()->mainFrame()->findAllElements("link[type=\"application/atom+xml\"]"));
QMap<KUrl, QString> map;
-
+
foreach(const QWebElement &el, col)
{
QString urlString;
diff --git a/src/webview.cpp b/src/webview.cpp
index c15478c2..1ffb2f1e 100644
--- a/src/webview.cpp
+++ b/src/webview.cpp
@@ -36,7 +36,7 @@
#include "mainwindow.h"
#include "mainview.h"
#include "webpage.h"
-#include "bookmarksmanager.h"
+#include "bookmarkprovider.h"
#include "searchengine.h"
#include "websnap.h"
@@ -79,8 +79,8 @@ WebView::WebView(QWidget* parent)
{
WebPage *page = new WebPage(this);
setPage(page);
-
- // // NOTE This is a lot hackish. We copied it from Arora, but using a "Windows Style"
+
+ // // NOTE This is a lot hackish. We copied it from Arora, but using a "Windows Style"
// // seems really a pity to me. The problem is that using a KStyle everything seems "broken"
// // (at least with dark colors). So I think the code should be somthing like:
// KStyle s;
@@ -93,7 +93,7 @@ WebView::WebView(QWidget* parent)
p = s.standardPalette();
setPalette(p);
}
-
+
// download system
connect(this, SIGNAL(linkShiftClicked(const KUrl &)), page, SLOT(downloadUrl(const KUrl &)));
connect(page, SIGNAL(downloadRequested(const QNetworkRequest &)), page, SLOT(downloadRequest(const QNetworkRequest &)));
@@ -126,7 +126,7 @@ WebView::~WebView()
disconnect();
WebPage* p = page();
-
+
QPixmap preview = WebSnap::renderClosingPagePreview(*p);
QString path = WebSnap::imagePathFromUrl(p->mainFrame()->url().toString());
QFile::remove(path);
@@ -168,7 +168,7 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
menu.addAction(pageAction(KWebPage::DownloadLinkToDisk));
menu.addAction(pageAction(KWebPage::CopyLinkToClipboard));
- menu.addSeparator();
+ menu.addSeparator();
}
// is content editable && selected? Add CUT
@@ -215,7 +215,7 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
}
menu.addSeparator();
-
+
menu.addAction(inspectAction);
// TODO Add translate, show translation
}
@@ -234,7 +234,7 @@ void WebView::contextMenuEvent(QContextMenuEvent *event)
menu.addAction(pageAction(KWebPage::DownloadImageToDisk));
menu.addAction(pageAction(KWebPage::CopyImageToClipboard));
menu.addSeparator();
-
+
menu.addAction(inspectAction);
}
diff --git a/src/zoombar.cpp b/src/zoombar.cpp
index b07aee03..041e6118 100644
--- a/src/zoombar.cpp
+++ b/src/zoombar.cpp
@@ -36,6 +36,7 @@
#include <KIcon>
#include <KStandardAction>
#include <KAction>
+#include <KLocalizedString>
// Qt Includes
#include <QtGui/QHBoxLayout>
@@ -57,7 +58,7 @@ ZoomBar::ZoomBar(QWidget *parent)
QToolButton *hideButton = new QToolButton(this);
hideButton->setAutoRaise(true);
- hideButton->setIcon(KIcon("dialog-close"));
+ hideButton->setIcon(KIcon("dialog-close"));
connect(hideButton, SIGNAL(clicked()), this, SLOT(hide()));
layout->addWidget(hideButton);
diff --git a/src/bookmarks/bookmarksmanager.h b/src/bookmarks/bookmarkprovider.h
index 0c2b9ee2..e21bd227 100644
--- a/src/bookmarks/bookmarksmanager.h
+++ b/src/bookmarks/bookmarkprovider.h
@@ -27,30 +27,38 @@
* ============================================================ */
-#ifndef BOOKMARKS_H
-#define BOOKMARKS_H
+#ifndef BOOKMARKPROVIDER_H
+#define BOOKMARKPROVIDER_H
// Rekonq Includes
#include "rekonq_defines.h"
-// KDE Includes
-#include <KBookmarkMenu>
-#include <KToolBar>
+// Qt Includes
+#include <QObject>
// Forward Declarations
class BookmarksPanel;
class BookmarkToolBar;
class BookmarkOwner;
+class KAction;
+class KActionCollection;
+class KActionMenu;
+class KBookmark;
+class KBookmarkGroup;
+class KBookmarkManager;
+class KToolBar;
+class KUrl;
+
+class QAction;
+class QPoint;
/**
* This class represent the interface to rekonq bookmarks system.
* All rekonq needs (Bookmarks Menu, Bookmarks Toolbar) is provided
* from this class.
- * So it implements code to have each one
- *
- *
+ * So it implements code to have each one.
*/
class BookmarkProvider : public QObject
{
@@ -60,11 +68,10 @@ public:
/**
* @short Class constructor.
* Connect BookmarksProvider with bookmarks source
- * (actually konqueror's bookmarks)
- * @param parent The MainWindow to provide bookmarks objects
- *
+ * (actually konqueror's bookmarks).
+ * @param parent The MainWindow to provide bookmarks objects.
*/
- BookmarkProvider(QObject* parent = 0);
+ BookmarkProvider(QObject *parent = 0);
~BookmarkProvider();
/**
@@ -72,14 +79,16 @@ public:
* @param the parent widget
* @return the Bookmarks Menu
*/
- KActionMenu *bookmarkActionMenu(QWidget *parent);
+ KActionMenu* bookmarkActionMenu(QWidget *parent);
/**
* @short set the Bookmarks Toolbar Action
*/
- void registerBookmarkBar(BookmarkToolBar *);
+ void registerBookmarkBar(BookmarkToolBar *toolbar);
+ void removeBookmarkBar(BookmarkToolBar *toolbar);
- void removeToolBar(BookmarkToolBar *);
+ void registerBookmarkPanel(BookmarksPanel *panel);
+ void removeBookmarkPanel(BookmarksPanel *panel);
/**
* @short Get action by name
@@ -88,7 +97,7 @@ public:
* @param name Name of action you want to get
* @return It returns actions if one exists or empty object
*/
- QAction *actionByName(const QString &name);
+ QAction* actionByName(const QString &name);
/**
* returns Bookmark Manager root group
@@ -97,22 +106,17 @@ public:
*/
KBookmarkGroup rootGroup();
- inline KBookmarkManager *bookmarkManager() { return m_manager; }
+ inline KBookmarkManager* bookmarkManager() { return m_manager; }
- inline BookmarkOwner *bookmarkOwner() { return m_owner; }
+ inline BookmarkOwner* bookmarkOwner() { return m_owner; }
- QList<KBookmark> find(QString text);
-
- void registerBookmarkPanel(BookmarksPanel *panel);
- void removeBookmarkPanel(BookmarksPanel *panel);
+ QList<KBookmark> find(const QString &text);
KBookmark bookmarkForUrl(const KUrl &url);
signals:
/**
* @short This signal is emitted when an url has to be loaded
- *
- * @param url the URL to load
*/
void openUrl(const KUrl &, const Rekonq::OpenType &);
@@ -128,11 +132,11 @@ public slots:
* @short Waits for signal that the group with the address has been modified by the caller.
* Waits for signal that the group (or any of its children) with the address
* @p groupAddress (e.g. "/4/5") has been modified by the caller @p caller.
* @param group bookmark group address
* @param caller caller that modified the bookmarks
* @see KBookmarkManager::changed
*/
- void slotBookmarksChanged(const QString &group, const QString &caller);
+ void slotBookmarksChanged(const QString &groupAddress, const QString &caller);
void fillBookmarkBar(BookmarkToolBar *toolBar);
private slots:
@@ -140,19 +144,16 @@ private slots:
void slotPanelChanged();
private:
- QList<KBookmark> find(QList<KBookmark> list, const KBookmark &bookmark, QString text);
+ void find(QList<KBookmark> *list, const KBookmark &bookmark, const QString &text);
- QString titleForBookmarkUrl(const KBookmark &bookmark, const QString &url);
KBookmark bookmarkForUrl(const KBookmark &bookmark, const KUrl &url);
KBookmarkManager *m_manager;
BookmarkOwner *m_owner;
KActionCollection *m_actionCollection;
- QList<BookmarkToolBar *> m_bookmarkToolBars;
+ QList<BookmarkToolBar*> m_bookmarkToolBars;
QList<BookmarksPanel*> m_bookmarkPanels;
-
- KActionMenu *_bookmarkActionMenu;
};
-#endif
+#endif // BOOKMARKPROVIDER_H
@@ -128,11 +132,11 @@ public slots:
* Waits for signal that the group (or any of its children) with the address
* @p groupAddress (e.g. "/4/5") has been modified by the caller @p caller.
- * @param group bookmark group address
+ * @param groupAddress bookmark group address
* @param caller caller that modified the bookmarks
* @see KBookmarkManager::changed